<?php
/* Copyright (C) Youbility Software - All Rights Reserved
 * www.youbility.de
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */

class Semknox_ProductSearch_Block_Admin_Info extends Mage_Adminhtml_Block_System_Config_Form_Fieldset
{

    protected $_store;


    public function __construct()
    {

       $this->_store = Mage::getSingleton('adminhtml/config_data')->getStore();

    }

    public function render(Varien_Data_Form_Element_Abstract $element)
    {
        /** @var Varien_Data_Form_Element_Abstract $elemet  */
        /** @var Semknox_ProductSearch_Helper_Data $helper  */
        $section = $element->getData()['container'];

        $storeViewMsg = $this->getStoreViewMessage();

        $messages = array();

        if($this->_store)
        {
            $messages[] = $this->getAccountStatus();

            $messages[] = $this->getExtensionStatus($section);

            $messages[] = $this->getExtensionVersion();

            $messages[] = $this->getExtensionModusStatus($section);

        } else {

            $messages[] = $storeViewMsg;
        }

        if(count($messages))
        {
            return '<div id="messages"><ul class="messages">'.implode($messages).'</ul></div>';
        }

        return '';
    }


    public function getExtensionStatus($section)
    {

        if(!$section->getElement('semknoxps_login')) return '';

        /**
         * @var Semknox_ProductSearch_Helper_Data $helper
         */
        $helper = Mage::helper('semknoxps');

        $authStatus = $helper->getSemknoxCredentialsStatus();

        switch ($authStatus){

            case -1 :
                $status = $this->__('Failed');
                $msgtype = 'error-msg';
                break;

            case 1 :
                $status = $this->__('Logged in');
                $msgtype = 'success-msg';
                break;

            default:
                $status = $this->__('Not Logged in');
                $msgtype = 'notice-msg';
                break;

        }

        $statusMsg = '<li class="'.$msgtype.' apiAuthMsg"><ul><li>'.$this->__('API-Authentication Status:').' '.$status.'</li></ul></li>';

        return  $statusMsg;

    }

    public function getExtensionVersion()
    {

        /**
         * @var Semknox_ProductSearch_Helper_Data $helper
         */
        $helper = Mage::helper('semknoxps');
        $msgtype = 'notice-msg';

        // values called later by ajax for performance reasons...
        $statusMsg = '<li class="'.$msgtype.' extensionVersion" style="display: none"><ul><li>'.$this->__("New Version available: <strong class='lv'>?</strong> (Version installed: <strong class='cv'>?</strong>) - <a href='?'>download</a>").'</li></ul></li>';

        return  $statusMsg;

    }

    public function getExtensionModusStatus($section)
    {
        /**
         * @var Semknox_ProductSearch_Helper_Data $helper
         */
        $helper = Mage::helper('semknoxps');

        if(!$helper->isSandboxMode()) return '';

        $wording = $this->__('Sie befinden sich im <u>Sandbox-Modus</u>. Dies ist ein Testsystem.');
        $message = '';
        $editHere = false;

        if($section->getElement('semknoxps_login'))
        {
            $message .= '<li class="notice-msg apiAuthMsg"><ul><li>'.$wording.'</li></ul></li>';
            $editHere = "document.getElementById('semknoxps_login').scrollIntoView();return false;";
        } elseif($this->_store) {

            $url = Mage::getSingleton('adminhtml/url')->getUrl('*/system_config/edit/section/semknoxps/store/'.$this->_store);
            $editHere = "window.location.href='".$url."'; return false;";
        }

        if($editHere)
        {
            $editHere = ' <button onclick="'.$editHere.'">'.$this->__('Modus ändern').'</button>';
        }

        $message .= '<li class="notice-msg"><ul><li>'.$wording.$editHere.'</li></ul></li>';

        return $message;
    }

    public function getStoreViewMessage()
    {
        return  '<li class="notice-msg">'.$this->__('Attention: This Search Extension has to be configured seperatly for each StoreView').'</li>';

    }

    public function getAccountStatus()
    {
        $accountManager = Mage::getSingleton('semknoxps/accountManager');
        $accountStatus = $accountManager->getAccountStatus();

        $message = false;

        // if "validThrough" equals -1, account does not expiregit
        if(isset($accountStatus['validThrough']) && $accountStatus['validThrough'] && $accountStatus['validThrough'] != -1)
        {
            $today = time();
            $validTo =  $accountStatus['validThrough'];
            $diff = $validTo - $today;

            $daysLeft = floor( $diff / (60*60*24) );

            /**
             * @var Semknox_ProductSearch_Helper_Data $helper
             */
            $helper = Mage::helper('semknoxps');

            if($daysLeft > 0 && $daysLeft <= 14)
            {
                $message = $helper->__('Bitte beachten Sie, dass Ihr APIKey in %s Tagen (am %s) ausläuft.', $daysLeft, date('d.m.Y',$validTo));
            }
            else if($daysLeft <= 0)
            {
                $message = $helper->__('Ihr APIKey ist abgelaufen. (letzte Gültigkeit: %s)', date('d.m.Y',$validTo));
            }


        }
        else if(isset($accountStatus['status']) and $accountStatus['status'] === 'TIMEOUT')
        {
            $message = 'API Timeout occurred';
        }

        if($message)
        {
            return '<li class="error-msg"><ul><li><span>'.$message.'</span></li></ul></li>';
        }

        return '';
    }

}
