<?php
/* Copyright (C) Youbility Software - All Rights Reserved
 * www.youbility.de
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */

class Semknox_ProductSearch_Block_Admin_Status extends Mage_Adminhtml_Block_System_Config_Form_Fieldset
{
    protected $_accountManager;

    protected $_helper;

    public function __construct()
    {
        $this->_accountManager = Mage::getSingleton('semknoxps/accountManager');
        $this->_helper = Mage::helper('semknoxps');
    }


    public function render(Varien_Data_Form_Element_Abstract $element)
    {

        /** @var Varien_Data_Form_Element_Abstract $elemet  */
        $section = $element->getData()['container'];

        return $this->html();
    }


    public function getAccountStatistic()
    {
        return $this->_accountManager->getAccountStatistic();
    }


    public function getAccountStatus()
    {
        return $this->_accountManager->getAccountStatus();
    }


    public function getAccountLoginUrl()
    {
        return $this->_accountManager->getAccountLoginUrl();
    }


    public function html()
    {
        if($this->_helper->getSemknoxCredentialsStatus() !== 1) return '';

        $accountData = $this->getAccountStatistic();

        $accountStatus = $this->getAccountStatus();

        $accountLoginUrl = $this->getAccountLoginUrl();

        $accountStatusMessage = (isset($accountStatus['status'])) ? $accountStatus['status'] : 'n.A.';

        $queriesLast24h = (isset($accountData['queriesLast24h'])) ? $accountData['queriesLast24h'] :'n.A.';
        $avgResponseTimeLast24h = (isset($accountData['avgResponseTimeLast24h'])) ? $accountData['avgResponseTimeLast24h'] :'n.A.';
        $productCount = (isset($accountData['productCount'])) ? $accountData['productCount'] :'n.A.';
        $spellingCorrectedLast24h = (isset($accountData['spellingCorrectedLast24h'])) ? $accountData['spellingCorrectedLast24h'] :'n.A.';

        if(is_int($spellingCorrectedLast24h) && is_int($queriesLast24h) && $queriesLast24h > 0)
        {
            $onePercent = $queriesLast24h / 100;
            $spellingCorrectedLast24h = $spellingCorrectedLast24h / $onePercent;
            $spellingCorrectedLast24h = round($spellingCorrectedLast24h, 2);
        }

        $iconCode = $this->_helper->getIconByStatus($accountStatusMessage);

        return "
          <div class='section-config'>

            <div class='entry-edit-head collapseable'>
                <a id='semknoxps_statistic-head' href='#' class='open' onclick='Fieldset.toggleCollapse(\"semknoxps_statistic\"); return false;'>".$this->_helper->__('Statistics')."</a>
            </div>
            <input id='semknoxps_statistic-state' name='config_state[semknoxps_statistic]' type='hidden' value='1'>

             <div class='sx-content-box' id='semknoxps_statistic'>
                 <div class='sx-content-position-relative'>

                    <div class='sx-apistatus-container sx-absolute-top-left'>
                        <div class='sx-back-office-mini-top'>".$this->__('api status')."</div>
                        <div class='sx-back-office-mini-mid'><span class='fa ".$iconCode."' aria-hidden='true'></span></div>
                        <div class='sx-back-office-mini-bot'>".$this->__($accountStatusMessage)."</div>
                    </div>

                    <div class='sx-statistic-main-container'>
                        <div class='sx-statistic-boxes'>
                            <div class='sx-statistic-box'>
                                <div class='sx-statisctic-box-header sx-uppercase'>".$this->__('Requests / last 24h')."</div><div class='sx-statisctic-box-content'><p><span>#</span> ". $queriesLast24h ." </p>".$this->__('various requests')."</div>
                            </div>
                            <div class='sx-statistic-box'>
                                <div class='sx-statisctic-box-header sx-uppercase'>".$this->__('Average response time / last 24h')."</div><div class='sx-statisctic-box-content'><p>". $avgResponseTimeLast24h ." <span sx-uppercase>".$this->__('ms')."</span></p>".$this->__('average response time')."</div>
                            </div>
                        </div>
                        <div class='sx-statistic-boxes'>
                            <div class='sx-statistic-box'>
                                <div class='sx-statisctic-box-header sx-uppercase'>".$this->__('Products')."</div><div class='sx-statisctic-box-content'><p><span>#</span> ". $productCount ." </p>".$this->__('products in the database')."</div>
                            </div>
                            <div class='sx-statistic-box'>
                                <div class='sx-statisctic-box-header sx-uppercase'>".$this->__('Spell-checking / last 24h')."</div><div class='sx-statisctic-box-content'><p>". $spellingCorrectedLast24h ." <span>%</span></p>".$this->__('corrected requests')."</div>
                            </div>
                        </div>
                    </div>

                    <a href='".$accountLoginUrl."' class='sx-back-office-container mini sx-absolute-top-right'>
                        <div class='sx-back-office-mini-top'>".$this->__('SEMKNOX')."</div>
                        <div class='sx-back-office-mini-mid'><span class='fa fa-external-link-square' aria-hidden='true'></span></div>
                        <div class='sx-back-office-mini-bot'>".$this->__('BackOffice')."</div>
                    </a>
                </div>
                ".$this->getCharts($accountData)."
             </div>
        </div>
        ";
    }


    public function getCharts($accountData)
    {
        $requiredData = array(
            'queriesByTime' => 'Line',
            'topCategories' => 'Bar'
        );

        $output = '';

        foreach($requiredData as $key => $type){

            $labelSuffix = '';

            if(!isset($accountData[$key]) || !is_array($accountData[$key]) || empty($accountData[$key])) continue;

            // for some reason its an array in an array
            if($key == 'topCategories' && isset($accountData[$key][0])) $accountData[$key] = $accountData[$key][0];

            if($key == 'queriesByTime'){
                sort($accountData[$key]);
                $labelSuffix = ' ('.array_sum($accountData[$key]).')';
            }

            $output .= '<script type="text/javascript">';
            $output .= 'jQuery(function () {

                    var '.$key.'Data = {
                        labels: ["'.implode('","',array_keys($accountData[$key])).'"],
                        datasets: [
                            {
                                fillColor: "rgba(202,220,230,0.5)", // Hintergrundfarbe
                                strokeColor: "rgba(202,220,230,1.0)", // Border/Linien-Farbe
                                pointColor: "rgba(169,199,212,0.8)", // Farbe der Punkten
                                pointStrokeColor: "#fff", // white
                                pointHighlightFill: "#fff", // white
                                pointHighlightStroke: "rgba(153,0,76,1)", // magenta
                                data: ['.implode(',',$accountData[$key]).']
                            }
                        ]
                    };
                    options = {
                        responsive: true,
                        maintainAspectRatio: false
                      };

                    var '.$key.'Elem = document.getElementById("'.$key.'").getContext("2d");
                    var '.$key.' = new Chart('.$key.'Elem).'. $type.'('.$key.'Data, options);

                });';

            $output .= '</script>';

            $output .= '<div class="sx-chart-wrapper"><div class="sx-chart-label">'.$this->_helper->__('Chart_label_'.$key).$labelSuffix.'</div><div class="sx-chart"><canvas id="'.$key.'"></canvas></div></div>';

        }

        return $output;
    }
}