<?php

/* Copyright (C) Youbility Software - All Rights Reserved
 * www.youbility.de
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */

class Semknox_ProductSearch_Block_Admin_Wizard extends Mage_Adminhtml_Block_System_Config_Form_Fieldset
{
    protected $_steps = array(
        1 => 'Zugangsdaten<br>Anschrift<br>AGB',
        2 => 'Datenupload',
        3 => 'Verarbeitung',
        4 => 'Filter wählen',
        5 => 'Fertig'
    );

    protected $_currentStoreId;
    protected $_helper;
    protected $_accountManager;

    protected $_agbFilePath;
    protected $_agbDate = '19.10.2016';


    public function __construct()
    {
        /**
         * @var Semknox_ProductSearch_Helper_Data $helper
         */
        $this->_helper = Mage::helper('semknoxps');
        $this->_currentStoreId = $this->_helper->getCurrentStoreId();
        $this->_accountManager = Mage::getSingleton('semknoxps/accountManager');


        $this->_agbFilePath = Mage::getModuleDir('Block', 'Semknox_ProductSearch').DS.'Block'.DS.'Admin'.DS.'agb.txt';
        $this->_agb = $this->_getAgb();

    }


    public function getAccountLoginUrl()
    {
        return $this->_accountManager->getAccountLoginUrl();
    }

    public function getCurrentStepNumber()
    {
        $storeId = $this->_currentStoreId;

        $currentStep = $this->_helper->getStoreConfig('semknoxps_wizard/general/currentStep', $storeId, 1);

        $currentStep = str_replace('done', '', $currentStep);

        $forceStep = Mage::app()->getRequest()->getParam('step', $currentStep);
        if( $forceStep != $currentStep)
        {
            $this->_helper->setCurrentWizardStep($forceStep, $storeId);
            return  $forceStep;
        }

        return $currentStep;
    }

    public function render(Varien_Data_Form_Element_Abstract $element)
    {
        $this->setElement($element);

        //logo über die Datei local/Semknox/ProductSearch/etc/system.xml und bei <label><![CDATA[<img src="/skin/frontend/base/default/semknox/images/logo.png" />]]></label>
        $output = array();


        // if Product upstream is disabled, dont do anything
        if($this->_helper->semknoxDisableProductUpstream( $this->_currentStoreId))
        {
            return $this->wizardDisabled();
        }

        $output[] = $this->getStepsProgressHeaderV();

        if (method_exists($this, 'getStep' . $this->getCurrentStepNumber() . 'Html')):
            $method   = 'getStep' . $this->getCurrentStepNumber() . 'Html';
            $output[] = '<div class="section-config">'.$this->$method().'</div>';
        endif;

        return implode($output);
    }


    public function getStepsProgressHeaderV()
    {
        $stepNr       = $this->getCurrentStepNumber();

        $style = '';
        
        if($stepNr == 5)
        {
            $style = "
                td.form-buttons{
                    display:none;
                }
            ";
        }
        
        $output  = '<style type="text/css">'.$style.'</style>';
        $output .= '<div class="sx-navigator clearfix">';


        foreach ($this->_steps as $number => $text) {
            $activeClass = $number <= $stepNr ? 'active' : '';

            if($number < $stepNr)
            {
                $output .= '<a href="?step='.$number.'" class="sx-steps '. $activeClass .'"><span class="sx-numbers">' . $number . '</span><span class="sx-info">' . $text . '</span></a>';
            } else {
                $output .= '<div class="sx-steps '. $activeClass .'"><span class="sx-numbers">' . $number . '</span><span class="sx-info">' . $text . '</span></div>';
            }

        }

        $output .= '</div> <!-- sx-navigator -->';

        $output .= '<input type="hidden" name="hiddenStoreId" value="" data-storeid="'. $this->_currentStoreId .'">';

        return $output;
    }


    /* hier funktion für step1 */
    public function getStep1Html()
    {

        /**
         * @var Semknox_ProductSearch_Helper_Data $helper
         */
        $helper  = $this->_helper;
        $storeId = $this->_currentStoreId;

        $apiKeyLogin = $helper->getStoreConfig('semknoxps/login/apiKey', $storeId, '');
        $customerIDLogin = $helper->getStoreConfig('semknoxps/login/customerId', $storeId, '');

        $apiKey = $helper->getStoreConfig('semknoxps_wizard/step1/apiKey', $storeId,  $apiKeyLogin);
        $customerID = $helper->getStoreConfig('semknoxps_wizard/step1/customerID', $storeId, $customerIDLogin);
        $account = $helper->getStoreConfig('semknoxps_wizard/step1/account', $storeId, 'existing');

        //Pfad zu dem Logo setzen
        $logo = Mage::getDesign()->getSkinUrl('semknox/images/logo_big.png');

        if($account == 'existing')
        {
            $accountExisting = ' checked ';
            $accountNew = ' ';
        } else {
            $accountExisting = '';
            $accountNew = ' checked ';
        }

        $outputTmp = "   
            <fieldset class='sx-frame config'>

                <img class='sx-logo' src='" . $logo . "' title='SEMKNOX'><br>
                <p class='sx-fontsize-one'>".$this->__('Danke, dass Sie sich für die Produktsuche von SEMKNOX entschieden haben.')."</p>

                <input type='radio' class='sx-radio-buttons' id='zugangsdaten' name='groups[step".$this->getCurrentStepNumber()."][fields][account][value]' value='existing' ". $accountExisting .">
                <label for='zugangsdaten'>".$this->__('Ich habe bereits Zugangsdaten für die SEMKNOX API')."</label><br>

                <div class='sx-customer-data'>

                    <label for='customerID'>".$this->__('Kundennummer: ')."</label>
                    <input type='text' id='sx-customerID' name='groups[step".$this->getCurrentStepNumber()."][fields][customerID][value]' value='".$customerID."'><br>

                    <label for='sx-api'>".$this->__('API Schlüssel: ')."</label>
                    <input type='text' id='sx-api' name='groups[step".$this->getCurrentStepNumber()."][fields][apiKey][value]' value='".$apiKey."' /> <br>
                    <button class='save sx-weiter' name='weiter' title='Save Config' onclick='configForm.submit()'><span>".$this->__('Weiter')."</span></button>
                </div>

                <div class='sx-step1-second-radio-section'>
                    <input type ='radio' class='sx-radio-buttons' id='produktsuche' name ='groups[step".$this->getCurrentStepNumber()."][fields][account][value]' value='new' ". $accountNew .">
                    <label for='produktsuche'>".$this->__('Ich möchte die SEMKNOX Produktsuche kostenlos testen: ')."</label> <br>

                    <div class='sx-content-text'>".$this->__('Weiterführende Informationen rund um die SEMKNOX Produktsuche finden Sie auf unserer Website unter <a href="http://semknox.com">semknox.com</a> ')."</div>
                    <div class='sx-content-text'><p class='sx-fontsize-two'>".$this->__('Registrierung: ')."<p></div>
                    <div class='sx-content-text'>".$this->__('Bitte füllen Sie folgendes Formular aus, um sich für einen kostenlosen und unverbindlichen Test der SEMKNOX Produktsuche zu registrieren. Der Test-Zeitraum
                    beträgt 2 Wochen und endet ohne Kontaktaufnahme Ihrerseits automatisch.')."
                </div>
                </div>"
                     . $this->getStep1Fieldsets() . "
                <div class='sx-content-text'>".$this->__('* Required Fields')."</div>
                <br>
                <div class='sx-content-text'><p class='sx-fontsize-two'>AGB:</p></div>
                <div class='sx-content-text'>".$this->__('Zum Fortsetzen des Vorgangs müssen Sie unseren AGB vom %s zustimmen: ', $this->_agbDate )."</div>
                <div class='sx-content-text'>
                <textarea rows='15' readonly>".$this->_agb."</textarea>
                </div>
                <div class='sx-content-text'>
                    <input type='checkbox' id='sx-agb' name='groups[step".$this->getCurrentStepNumber()."][fields][agb][value]'>
                    <label for='sx-agb'>".$this->__('Ich stimme den AGB vom %s der SEMKNOX GmbH zu.', $this->_agbDate )."</label>
                </div>
                <input type='hidden' id='sx-agbAccepted' name='groups[step".$this->getCurrentStepNumber()."][fields][agbAccepted][value]' value=''>
                <button class='save sx-weiter' name='weiter'><span>".$this->__('Weiter')."</span></button>
            </fieldset>
        ";

        return $outputTmp;
    }


    public function getStep1Fieldsets()
    {
        $stepData = Mage::getStoreConfig('semknoxps_wizard/step1', $this->_currentStoreId);

        $stepDataIdx = array('firstname','company','street','zip','lastname','streetNr','city','email','storeUrl','telefon', 'ustId');
        foreach($stepDataIdx as $index)
        {
            $stepData[$index] = (isset($stepData[$index])) ? $stepData[$index] : '';
        }

        return "
            <fieldset class='sx-inner-fieldset'>
                <legend>Rechnungsanschrift</legend>
                <div class='sx-form-list form-list'>
                    <label for='vorname'>".$this->__('firstname')."*</label><input type='text' id='vorname' name='groups[step".$this->getCurrentStepNumber()."][fields][firstname][value]' value='" . $stepData['firstname'] . "'>
                </div>
                <div class='sx-form-list form-list'>
                    <label for='name'>".$this->__('lastname')."*</label><input type='text' id='name' name='groups[step".$this->getCurrentStepNumber()."][fields][lastname][value]' value='" . $stepData['lastname'] . "' >
                </div>
                <div class='sx-form-list form-list'>
                    <label for='firma' id='firma'>".$this->__('company')."*</label><input type='text' id='firma' name='groups[step".$this->getCurrentStepNumber()."][fields][company][value]' value='" . $stepData['company'] . "' >
                    <p class='note'><span>".$this->__('  Rechnungsanschrift')."</span> </p>
                </div>
                <div class='sx-form-list form-list'>
                    <label for='ust'>".$this->__('Ust.-Id')."*</label><input type='text' id='ust' name='ust' value='" . $stepData['ustId'] . "' >
                </div>
                <div class='sx-form-list form-list'>
                    <label for='straße' id='straße'>".$this->__('street')."*</label><input type='text' id='straße' name='groups[step".$this->getCurrentStepNumber()."][fields][street][value]' value='" . $stepData['street'] . "' >
                    <p class='note'><span>".$this->__('  Rechnungsanschrift')."</span> </p>
</div>
                <div class='sx-form-list form-list'>
                     <label for='hausnummer' id='hausnummer'>".$this->__('housenumber')."*</label><input type='text' id='hausnummer' name='groups[step".$this->getCurrentStepNumber()."][fields][streetNr][value]' value='" . $stepData['streetNr'] . "' ><br>
                    <p class='note'><span>".$this->__('  Rechnungsanschrift')."</span> </p>
</div>
                <div class='sx-form-list form-list'>
                    <label for='plz' id='plz'>".$this->__('zip')."*</label><input type='text' id='plz' name='groups[step".$this->getCurrentStepNumber()."][fields][zip][value]' value='" . $stepData['zip'] . "' ><br>
                    <p class='note'><span>".$this->__('  Rechnungsanschrift')."</span> </p>
</div>
                <div class='sx-form-list form-list'>
                    <label for='stadt' id='stadt'>".$this->__('city')."*</label><input type='text' id='stadt' name='groups[step".$this->getCurrentStepNumber()."][fields][city][value]' value='" . $stepData['city'] . "' ><br>
                    <p class='note'><span>".$this->__('  Rechnungsanschrift')."</span> </p>

                  </div>
            </fieldset>

            <fieldset class='sx-inner-fieldset'>
                <legend>Weitere Daten</legend>
                <div class='sx-form-list form-list'>
                    <label for='email' id='email'>".$this->__('email')."*</label><input type = 'email' id='email' name='groups[step".$this->getCurrentStepNumber()."][fields][email][value]' value ='" . $stepData['email'] . "' ><br>
                    <p class='note sx-step1-max-width'><span>".$this->__(' An diese E-mail-Adresse wird der Zugang zum SEMKNOX BackOffice gesendet und dient zur Kommunikation mit Ihnen.')."</span> </p>    
</div>
<div class='sx-form-list form-list'>
                    <label for='telefon'>".$this->__('telefon')."*</label><input type='tel' id='telefon' name='groups[step".$this->getCurrentStepNumber()."][fields][telefon][value]' value='" . $stepData['telefon'] . "' ><br>
                </div>
                <div class='sx-form-list form-list'>
                    <label for='url' id='url'>".$this->__('storeUrl')."*</label><input type='url' id='url' name='groups[step".$this->getCurrentStepNumber()."][fields][storeUrl][value]' value='" . $stepData['storeUrl'] . "' ><br>
                    <p class='note sx-step1-max-width'><span>".$this->__(' Adresse des Webshops, auf dem die Suche zum Einsatz kommen soll.')."</span> </p>    

                </div>

            </fieldset>
        ";
    }


    public function getMoreSemknox()
    {
        return '
                <div style="display:none">    
                    <div><hr class="sx-trennlinie"></div>
                    <p class="sx-fontsize-one" >'.$this->__("Mehr zu SEMKNOX:").'</p>
                    <div class="sx-presentation"><p>'.$this->__("SEMKNOX Präsentation").'</p></div>
                </div>';
    }

    /* hier funktion für step2 */
    public function getStep2Html()
    {
        return '
            <fieldset class="sx-frame config">
                <h1>'.$this->__("Upload der Produktdaten").'</h1>
                <p>'.$this->__("Ihre Produktdaten werden nun zur SEMKNOX API exportiert. Dieser Vorgang kann in Abhängigkeit der Menge an Produkten und
                der Performance des Webshop-Servers mehrere Minuten dauern.").'</p>
                ' . $this->getProgressBar() . '
                <div class="sx-pause-button-container sx-visible">
                    <div>
                        <button type="button" class="sx-pause" name="initialupload" data-storeid="'. $this->_currentStoreId .'"
                                onclick="var event=new CustomEvent(\'startInitialProductUpload\', {detail:{sender:this}});document.dispatchEvent(event);"
                        ><span><span><span>'.$this->__("Start Initial Upload<span class='continue' style='display:none !important'>Continue Initial Upload</span><span class='pause' style='display:none !important'>Pause Initial Upload</span>"). '</span></span></span>
                        </button>
                    </div>

                    <div class="sx-button-beschreibung form-list">
                        <p class="note">'.$this->__("Sie können den Datenupload jederzeit pausieren und später fortsetzen. Wurde zu lange pausiert, startet der Upload erneut.").'</p>
                     </div>
                </div>

                <div class="sx-hidden">
                    <div class="sx-logo-text-mid sx-logo-visible-status">
                        <div class="sx-logo-mid"><span class="sx-fa fa fa-check-circle-o fa-3" aria-hidden="true"></span></div>
                        <div class="sx-text-mid">Der Produktupload ist abgeschlossen.</div>
                    </div>
                    <button class="save sx-weiter" name="weiter"><span>'.$this->__("Weiter").'</span></button>
                </div>
                ' . $this->getMoreSemknox() . '
            </fieldset>
            ';
    }


    public function getProgressBar()
    {
        $progressBarValue = 0;

        return "
            <div class='sx-wizzard sx-progress-container'>
                <div class='sx-wizzard sx-progress-bar' style='width:"   . $progressBarValue . "%'></div>
                <span class='sx-wizzard sx-progress-label sx-fontsize-two' >" . $progressBarValue . "%</span>
                <div class='sx-wizzard sx-progress-message'></div>
            </div>
        ";
    }


    /* hier funktion für step3 */
    public function getStep3Html()
    {


        return "
        <fieldset class='sx-frame config'>
  
        <p class='sx-fontsize-one'>".$this->__("Verarbeitung der Produktdaten")."</p>
        " . $this->getProgressBar() . "
        <div class='sx-visible'>
            <div class='sx-logo-text-mid sx-visible'>
                <div class='sx-logo-mid'><span class='sx-fa fa ".$this->_helper->getIconByStatus('PROCESSING_DATA')." fa-3' aria-hidden='true'></span></div>
                <div class='sx-text-mid'>".$this->__("Ihre Produktdaten werden zur Zeit auf den SEMKNOX Servern
                analysiert und verarbeitet. Dies kann je nach Komplexität der Daten unterschiedlich lange dauern.")."</div>
            </div>
        </div>

        <div class='sx-hidden'>
            <div class='sx-logo-text-mid sx-logo-visible-status'>
                <div class='sx-logo-mid'><span class='sx-fa fa ".$this->_helper->getIconByStatus('SEARCH_READY')." fa-3' aria-hidden='true'></span></div>
                <div class='sx-text-mid'>".$this->__("Die Verarbeitung Ihrer Produktdaten ist abgeschlossen.")."</div>
            </div>
            <button class='save sx-weiter' name='weiter'><span>".$this->__('Weiter')."</span></button>
        </div>

        " . $this->getMoreSemknox() . "
        
        </fieldset>
        <script>
            (function() {
                var interval;
                var checkStatus = function() {
                    jQuery.getJSON('". Mage::getUrl("adminhtml/semknox_productSearch_account/status", array('storeid' => $this->_currentStoreId)) ."', function(response)
                    {
                        if(response.status == 'SEARCH_READY') {
                            // update progress bar and show steps
                            jQuery('.sx-hidden,.sx-visible').toggle();
                            clearInterval(interval);
                            jQuery('.sx-progress-bar').addClass('success');
                            jQuery('.sx-progress-label').text('100 %');
                        }
                        else if(response.updateProgress)
                        {
                            var percent = response.updateProgress * 100;

                            var progressBar = jQuery('.sx-progress-bar');
                            var progressLabel = jQuery('.sx-progress-label');
                            
                            progressBar.width(percent + '%');
                            progressLabel.text(percent +' %');
                            
                            if(percent >= 52){
                                progressLabel.addClass('sx-percentage-white');
                            }
                        }
                    });
                };

                // check every ten seconds if the account is ready
                interval = window.setInterval(checkStatus, 10000);


            })();
        </script>
    ";
    }


    /* Hier Funktion für step4 */
    public function getStep4Html()
    {
        $accountManager = Mage::getSingleton('semknoxps/AccountManager');

        $filters = $accountManager->getAvailableFilters();
        //$filtersSet = $accountManager->getAvailableFiltersSet();
        $filtersInGroups = $accountManager->getAvailableFiltersGroupedByType();

        $html = "
        <script type='text/javascript'>
            var sxSetFilterUrl = '".$accountManager->getSetFiltersUrl()."';
            var sxApiKey = '".$this->_helper->semknoxApiKey()."';
            var sxCustomerId = '".$this->_helper->semknoxCustomerId()."';
            var sxAvailableFilters = ".json_encode($filters, false).";
        </script>
        <fieldset class='sx-frame config'>
        
            <p class='sx-fontsize-one'>".$this->__("Verfügbare Filter auswählen")."</p>
        
            <div class='sx-content-text'>
                ".$this->__("Im folgenden können Sie verschiedene Filter/Facetten auswählen, die SEMKNOX aus den zuvor übertragenen Produktdaten erstellt hat. Diese Filter werden dem Besucher neben dem Suchergebnis zur Verfeinerung der Produktliste angezeigt.")."
            </div>
            <div class='sx-filter-main-container clearfix'>";


        $groupIcon = array(
            'MULTI_SELECT' => 'fa-list',
            'RANGE' => 'fa-sliders',
        );


        foreach($filtersInGroups as $group => $filter):

            $icon = (isset($groupIcon[$group])) ? $groupIcon[$group] : 'fa-list';

            $html .= "<fieldset class='sx-filter-fieldset'>
                        <legend>".$this->__($group.'_FILTER')."</legend>
                        <div class='sx-filter-icon-wrapper'>
                            <span class='sx-fa fa ".$icon." fa-5' aria-hidden='true'></span>
                        </div>
                        <div class='sx-filter-values'>";

            foreach($filter as $f):

                $html .= '<label>
                              <input type="checkbox" class="sxFilter"
                                     data-filter=\''.json_encode($f, JSON_HEX_APOS).'\'
                                     name="'. $f['viewName'] .'"
                                    value="'.$f['id'].'"
                                    '. ($f['set'] ? 'checked' : '') .'
                              > '. $f['viewName'] .'
                          </label><br>';

            endforeach;

            $html .= "  </div> <!-- sx-float-right-container -->
                      </fieldset> <!-- sx-filter-left-fieldset -->";

        endforeach;

        $html .= "
                      </div> <!-- sx-filter-main-container -->
                      <div class='sx-content-text'>".$this->__("Weitere Einstellmöglichkeiten zu den Filtern (Umbenennung, Positionierung, Auswahl von Unteroptionen) finden Sie im SEMKNOX Backoffice nach Abschluss der Installation.")."</div>
                      <button class='save sx-weiter' name='weiter'><span>".$this->__("Weiter")."</span></button>
            </fieldset> <!-- sx-frame -->

        </fieldset>
        ";

        return $html;
    }


    /* hier funktion für step5 */
    public function getStep5Html()
    {

        /**
         * @var Semknox_ProductSearch_Model_AuthenticationManager $authManager
         */
        $accountLoginUrl = $this->getAccountLoginUrl();
        $productManager = Mage::getModel('semknoxps/productManager');
        $shopUrl = Mage::app()->getStore($this->_currentStoreId)->getBaseUrl(Mage_Core_Model_Store::URL_TYPE_LINK);

        return "
            <fieldset class='sx-frame config'>       
            <div class='sx-logo-text-mid'>
                <div class='sx-logo-mid'><span class='sx-fa fa fa-flag-checkered fa-7' aria-hidden='true'></span></div>
                <div class='sx-text-mid sx-text-small-mid'><p class='sx-fontsize-one'>".$this->__("Fertig!")."</p></div>
            </div>
            <div class='sx-content-center'>
                <ul class='checklist-list'>
                    <li><span class='sx-fa fa fa-check-circle-o sx-fa-checklist'></span>  ".$this->__("Zugangsdaten eingerichtet")."</li>
                    <li><span class='sx-fa fa fa-check-circle-o sx-fa-checklist'></span>  ".$this->__("Produkte hochgeladen")."</li>
                    <li><span class='sx-fa fa fa-check-circle-o sx-fa-checklist'></span>  ".$this->__("Filter aktiviert")."</li>
                </ul>
            </div>
            <div class='sx-content-center'>
            <p class='sx-fontsize-two'>".$this->__("Probieren Sie die Suche gleich hier aus:")."</p></div>

            <div class='sx-unibox'>
                <link rel='stylesheet' href='" . Mage::getModel('core/design_package')->getSkinUrl('semknox/lib/unibox/unibox.min.css') . "'>
                <script type='text/javascript' src='" . Mage::getModel('core/design_package')->getSkinUrl('semknox/lib/unibox/unibox.min.js') . "'></script>
                <script type='text/javascript'>

                    jQuery(document).ready(function() {

                        var settings = {
                          // these are required:
                          suggestUrl: '" . $productManager->getSuggestUrl() . "&query=', // the URL that provides the data for the suggest
                          // these are optional:
                          searchBoxContainerSelector: undefined, // suggest will be attached to this container, by default it will be the parent of the search input (e.g. #searchBox)
                          instantVisualFeedback: 'all', // where the instant visual feedback should be shown, 'top', 'bottom', 'all', or 'none', default: 'all'
                          ivfImagePath: 'https://login.semknox.com/images/ivf/', // the path to prepend to the instant visual feedback images
                          ivfImageOffset: -80, // the vertical offset of the ivf images
                          missingErrorImage: undefined, // a default image in case a suggested image was not found
                          throttleTime: 300, // the number of milliseconds before the suggest is triggered after finished input, default: 300ms
                          extraHtml: undefined, // extra HTML code that is shown in each search suggest
                          placeholder: undefined, // the placeholder to be put in the search field
                          highlight: true, // whether matched words should be highlighted, default: true
                          queryVisualizationHeadline: '', // A headline for the image visualization, default: empty
                          animationSpeed: 300, // speed of the animations, default: 300ms
                          enterCallback: undefined, // callback on what should happen when enter is pressed while the focus is in the search field
                          enterResultCallback: undefined, // callback on what should happen when enter is pressed while the focus is on one of the suggests, default: undefined, meaning the link will be followed
                          typeCallback: undefined, // callback on keydown events in the search box
                          focusCallback: undefined, // callback on focus events on the search box
                          blurCallback: undefined, // callback on blur events on the search box
                          minChars: 3, // minimum number of characters before the suggests shows, default: 3
                          maxWidth: 400 // the maximum width of the suggest box, default: as wide as the input box
                        };

                        // apply the settings to an input that should get the unibox
                        jQuery('#sx-unibox-backend').keydown(function(event){
                            if(event.keyCode == 13) {
                              event.preventDefault();
                              return false;
                            }
                        });

                        jQuery('#sx-unibox-backend').unibox(settings);

                    })

                </script>
                <input type='search' placeholder='". $this->__("Probieren Sie die Suche gleich hier aus:") ."'  id='sx-unibox-backend'  >
            </div>

            <div class='sx-content-center'>
            <a href='$shopUrl' target='blank' class='sx-blue-button'>
                ".$this->__("ZUM SHOP")." <span class='fa fa-external-link-square fa-lg'></span>
            </a>
            <p>".$this->_helper->__("Zum <a href='$accountLoginUrl' target='blank' class='sx-blue-link'>SEMKNOX BackOffice <span class='fa fa-external-link-square'></span></a>", $this->getAccountLoginUrl())."</p>
            </div>

            </fieldset>
    ";
    }


    protected function _getAgb(){

        $agb = file_get_contents($this->_agbFilePath);

        return $agb;

    }

    protected function wizardDisabled()
    {

        return  '<ul class="messages"><li class="notice-msg">'.$this->__("Um diese Funktion nutzen zu können, müssen Sie den Produktupload in den Erweiterten Einstellungen im aktuellen Scope aktivieren.").'</li></ul>';

    }


}

