<?php
/**
 * Magento
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/osl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@magento.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade Magento to newer
 * versions in the future. If you wish to customize Magento for your
 * needs please refer to http://www.magento.com for more information.
 *
 * @category    Mage
 * @package     Mage_CatalogSearch
 * @copyright  Copyright (c) 2006-2015 X.commerce, Inc. (http://www.magento.com)
 * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 */

/**
 * Layered Navigation block for search
 *
 */
class Semknox_ProductSearch_Block_CatalogSearch_Layer_Filter extends Mage_Core_Block_Template//Mage_Catalog_Block_Layer_View
{

    public function getAttributeId()
    {
        return $this->filter['id'];
    }
    

    public function getType()
    {
        return $this->filter['type'];
    }


    public function getId()
    {
        return $this->filter['id'];
    }

    public function getItemsCount()
    {
        if($this->getType() == 'RANGE') return 1;

        return count($this->filter['options']);
    }


    public function getName()
    {
        return $this->filter['viewName'];
    }


    public function getItems()
    {
        $items = array();

        foreach($this->filter['options'] as $key =>  $option)
        {
            $items[$key] = Mage::getModel('semknoxps/catalogSearch_layer_filter_item', array( 'filterId' => $this->getId(), 'item' => $option ));
        }

        return $items;
    }

    public function getRangeMin()
    {
        return (isset($this->filter['min']) && $this->filter['min'] > 0) ? $this->filter['min'] : 0;
    }

    public function getRangeMax()
    {
        return (isset($this->filter['max']) && $this->filter['max'] > 0) ? $this->filter['max'] : 99999;
    }

    public function getSetMin()
    {
        return (isset($this->filter['set']['minValue'])) ? $this->filter['set']['minValue'] : $this->getRangeMin();
    }

    public function getSetMax()
    {
        return (isset($this->filter['set']['maxValue'])) ? $this->filter['set']['maxValue'] : $this->getRangeMax();
    }

    public function getRangeStep()
    {
        return (isset($this->filter['step'])) ? $this->filter['step'] : 1;
    }

    public function getUnitName()
    {
        return (isset($this->filter['unitName']) && strlen(trim($this->filter['unitName']))) ? ' '.$this->filter['unitName'] : '';
    }

    public function getIdNameCss()
    {
        return (isset($this->filter['idName'])) ? str_replace('.','',$this->filter['idName']) : '';
    }

    public function getHtml()
    {
        if($this->getType() == 'RANGE')
        {
            $request = Mage::app()->getRequest();
            $query = $request->getParams();
            if(isset($query['filter'][$this->getId()]['min'])) unset($query['filter'][$this->getId()]['min']);
            if(isset($query['filter'][$this->getId()]['max'])) unset($query['filter'][$this->getId()]['max']);
            if(isset($query['filter'][$this->getId()]['unitName'])) unset($query['filter'][$this->getId()]['unitName']);


            /* @var Semknox_ProductSearch_Helper_Data $helper */
            $helper = Mage::helper('semknoxps');

            if($helper->semknoxSeoUrlIsActive()) {

                $slug = $helper->getLastDirectoryInUrl();

            } else {

                $slug = $helper->getResultsUrl();
            }

            $url = Mage::getUrl($slug, array(
                '_query' => $query
            ));


            $html  = $this->getLayout()->createBlock('page/html')->setTemplate('semknoxps/filteritem.phtml');
            $html->setData('item', $this);
            $html->setData('url', $url);

            $min = $this->getRangeMin();
            $max = $this->getRangeMax();
            $step = $this->getRangeStep();

            $minStart = $this->getSetMin();
            $maxStart = $this->getSetMax();

            $unitName = $this->getUnitName();


            $html->setData('min', $min);
            $html->setData('max', $max);
            $html->setData('step', $step);
            $html->setData('min_start', $minStart);
            $html->setData('max_start', $maxStart);

            $html->setData('unit_name',  $unitName);

            return $html->toHtml();


        } else {

            $items = $this->getItems();

            $this->setTemplate('catalog/layer/filter.phtml');
            $this->setItems($items);
            return '<div class="sx'.$this->getType().' '.$this->getIdNameCss().'">'.$this->toHtml().'</div>';
        }





    }

    public function shouldDisplayProductCount()
    {
        return true;
    }


}
