<?php
/* Copyright (C) Youbility Software - All Rights Reserved
 * www.youbility.de
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */

class Semknox_ProductSearch_Block_CatalogSearch_Results extends Mage_CatalogSearch_Block_Result
{
    /**
     * Catalog Product collection
     *
     * @var Mage_CatalogSearch_Model_Resource_Fulltext_Collection
     */


    public function getNoResultText()
    {
        /* @var Semknox_ProductSearch_Helper_Data $helper */
        $helper = Mage::helper('semknoxps');
        $layer = $this->getListBlock()->getLayer();

        if($helper->semknoxShowQueryInterpretation() && strlen($layer->getSemknoxMessage()) && !$layer->getCollectionHasProducts()/*!$layer->getSemknoxHasResults()*/)
        {
            return $layer->getSemknoxMessage();
        }

        return parent::getNoResultText();

    }


    public function getNoteMessages()
    {
        /* @var Semknox_ProductSearch_Helper_Data $helper */
        $messages = parent::getNoteMessages();
        $layer = $this->getListBlock()->getLayer();
        $helper = Mage::helper('semknoxps');

        /** @var Semknox_ProductSearch_Model_ProductResult  $productResult */
        $productResult = Mage::getSingleton('semknoxps/ProductResult');
        $contentSearchResults = $helper->semknoxShowSiteSearch360Results() && $productResult->getContentSearchResults();

        if(!$contentSearchResults && $helper->semknoxShowQueryInterpretation() && strlen($layer->getSemknoxMessage()) && $layer->getSemknoxHasResults() && $layer->getCollectionHasProducts())
        {
            $messages[] = $this->getSemknoxExplanation();
        }

        if(!$contentSearchResults && $helper->showAvailableOrdersToolbar() && $orders = $this->getAvailableOrdersHtml())
        {
            $messages[] = $orders;
        }

        $debug = Mage::app()->getRequest()->getParam('swtw');
        if($debug && $debug == 100 && $productIds = $layer->productIds)
        {
            $messages[] = '<b style="color: red">';
            $messages[] = 'QUERY: <i>'.$this->helper('catalogsearch')->getEscapedQueryText().'</i>';
            $messages[] = 'API_LIMIT: <i>'.$layer->_api_limit .'</i>';
            $messages[] = 'PRODUCTS_COUNT_BY_API: '.$layer->getSemknoxHasResults();
            $messages[] = 'PRODUCTS_COUNT_IN_RESPONSE: '.count($productIds);
            $messages[] = 'PRODUCTS: ['.implode(', ',$productIds).']';
            $messages[] = '</b>';
        }

        return $messages;
    }


    protected function getSemknoxExplanation()
    {
        $layer = $this->getListBlock()->getLayer();
        return '<font id="sxExplanation">'.$layer->getSemknoxMessage().'</font>';
    }


    public function getAvailableOrdersHtml()
    {
        $layer = $this->getListBlock()->getLayer();
        $orders = $layer->getOrders();

        if($layer->getSemknoxHasResults() && !empty($orders) && is_array($orders))
        {
            $query = Mage::app()->getRequest()->getParams();

            $msg = array();

            foreach ($orders as $key => $order) {

                /* @var Semknox_ProductSearch_Helper_Data $helper */
                $helper = Mage::helper('semknoxps');
                if($helper->semknoxSeoUrlIsActive())
                {
                    $query['order'] = $order['id'];
                    $url = Mage::getUrl($helper->getLastDirectoryInUrl(),
                        array(
                            '_query' => $query
                        ));

                } else {

                    $query['order'] = $order['id'];
                    $url = Mage::getUrl($helper->getResultsUrl(),
                        array(
                            '_query' => $query
                        ));

                }

                // put direction change to currently set order
                if(isset($order['set']))
                {
                    // relevance Order (always desc)
                    if($order['id'] == 'none'){
                        $url = str_replace('dir=desc', 'dir=asc', strtolower($url));
                    }
                    // currently desc set
                    elseif(stripos($url, 'dir=desc') !== false)
                    {
                        $url = str_replace('dir=desc', 'dir=asc', strtolower($url));
                    }
                    // currently asc set
                    elseif(stripos($url, 'dir=asc') !== false)
                    {
                        $url = str_replace('dir=asc', 'dir=desc', strtolower($url));
                    }
                    // nothing set
                    else {
                        $direction = ( $order['set'] == 'desc') ? 'asc' : 'desc';
                        $url .= '&dir='.$direction;
                    }

                }

                $order['url'] = strtolower($url);

                $orders[$key] = $order;

            }

            if(count($orders)){

                $block = $this->getLayout()->createBlock('page/html')->setTemplate('semknoxps/ordertoolbar.phtml');
                $block->setData('orders', $orders);

                return $block->toHtml();

            }

        }

        return false;
    }

    public function getHeaderText()
    {
        $headerText = parent::getHeaderText();

        if($headerText || $headerText === false) $return = $headerText;

        else $return = $this->__("Search results for '%s'", '<font id="sxSearchString">'.$this->helper('catalogsearch')->getEscapedQueryText().'</font>');


        return $return;

    }


    public function getContentTabsHtml($contentSearchResults)
    {
        $tabs = $this->getLayout()->createBlock('page/html')->setTemplate('semknoxps/contenttabs.phtml');
        $tabs->setData('content', $contentSearchResults);

        return $tabs->toHtml();
    }

    public function getProductListHtml(){

        /** @var Semknox_ProductSearch_Model_ProductResult  $productResult */
        $productResult = Mage::getSingleton('semknoxps/ProductResult');
        $helper = Mage::helper('semknoxps');

        $contentSearchResults = $productResult->getContentSearchResults();

        if($contentSearchResults && $helper->semknoxShowSiteSearch360Results()){

            $tabs = $this->getLayout()->createBlock('page/html')->setTemplate('semknoxps/tabs.phtml');
            $contenttabs = $this->getContentTabsHtml($contentSearchResults);

            $tabs->setData('contenttabs', $contenttabs);

            $products = $this->getSemknoxExplanation();
            $products .= $this->getAvailableOrdersHtml();
            $products .= parent::getProductListHtml();
            $tabs->setData('products',$products);

            return $tabs->toHtml();

        } else {

            return parent::getProductListHtml();

        }

    }
}
