<?php
/* Copyright (C) Youbility Software - All Rights Reserved
 * www.youbility.de
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */

class Semknox_ProductSearch_Block_Unibox extends Mage_Core_Block_Template
{

    public function getUniboxData($key, $defaultValue = '')
    {

        $value = Mage::getStoreConfig('semknoxps/unibox/'.$key);

        if($value == "0") return $value;

        if(!$value)
        {
            if(is_integer($defaultValue) || $defaultValue == 'undefined')  return $defaultValue;

            if(is_bool($defaultValue))  return ($defaultValue) ? 'true' : 'false';

            return '"'.$defaultValue.'"';

        } else {

            if(is_integer($defaultValue) || $value == 'undefined')  return $value;

            if(is_bool($defaultValue))  return ($value) ? 'true' : 'false';

            return '"'.$value.'"';

        }

    }

    protected function _toHtml()
    {
        /* @var Semknox_ProductSearch_Helper_Data $helper */
        $helper = Mage::helper('semknoxps');

        if(!$helper->semknoxpsUniboxIsActive()) return '';

        $html  = $this->getLayout()->createBlock('page/html')->setTemplate('semknoxps/unibox.phtml');

        $uniboxConfig = array(

            'suggestOrder'          => "['Produkte','Kategorien','Suchvorschläge','Marken']",
            'suggestUrl'            => $this->getUniboxSuggestUrl(),
            'instantVisualFeedback' => $this->getUniboxData('instantVisualFeedback'),
            'ivfImagePath'          => $this->getUniboxData('ivfImagePath','https://login.semknox.com/images/ivf/'),
            'ivfImageOffset'        => $this->getUniboxData('ivfImageOffset', -80),
            'missingErrorImage'     => $this->getUniboxData('missingErrorImage', 'undefined'),
            'throttleTime'          => $this->getUniboxData('throttleTime', 300),
            'placeholder'           => $this->getUniboxData('placeholder', 'undefined'),
            'highlight'             => $this->getUniboxData('highlight', true),
            'queryVisualizationHeadline'    => $this->getUniboxData('queryVisualizationHeadline'),
            'animationSpeed'        => $this->getUniboxData('animationSpeed', 300),
            'callbacks'             => array(
                'enter'             => "function(searchTerm) { 
                							if(searchTerm.length >= ". Mage::getStoreConfig('catalog/search/min_query_length', 2)."){
                								jQuery(this).closest('form').submit();
                							} else {
                								jQuery(this).closest('input[name=q]').addClass('validation-failed');
                							}
                						}",
                'type'				=>  "function(event, searchTerm) { 
                							if(searchTerm.length >= ".Mage::getStoreConfig('catalog/search/min_query_length', 2)."){
                								jQuery(this).closest('input[name=q]').removeClass('validation-failed');
                							} else {
                								jQuery(this).closest('input[name=q]').addClass('validation-failed');
                							}
                						}",
                'enterResult'       => 'function(productName, productLink) {
                                            if((typeof productLink === "undefined" || ! productLink) && productName) {
                                                var $q = jQuery("input[name=q]:visible");
                                                $q.val(productName)
                                                     .closest("form")
                                                     .submit();
                                            }
                                            else if(productLink) {
                                                window.location.href = productLink;
                                            }
                                        }',

            ),
            'minChars'              => $this->getUniboxData('minChars', 3),
            'maxWidth'              => $this->getUniboxData('maxWidth', 400),
            'showImagesSuggestions' => true,

        );

        $html->setData('uniboxConfig', $uniboxConfig);

        return $html->toHtml();

    }

    public function getUniboxSuggestUrl()
    {
        /* @var Semknox_ProductSearch_Helper_Data $helper */
        $helper = Mage::helper('semknoxps');

        /**
         * @var Semknox_ProductSearch_Model_AuthenticationManager $authManager
         */
        $productManager = Mage::getModel('semknoxps/productManager');

        $params = '';

        $params .= '&limit='.$this->getUniboxData('limit', 10);
        $params .= '&limitBrand='.$this->getUniboxData('limitBrand', -1);
        $params .= '&limitSearch='.$this->getUniboxData('limitSearch', -1);
        $params .= '&limitContent='.$this->getUniboxData('limitContent', -1);
        $params .= '&limitCategory='.$this->getUniboxData('limitCategory', -1);
        $params .= '&limitProduct='.$this->getUniboxData('limitProduct', -1);

        $url = $productManager->getSuggestUrl();
        $helper = Mage::helper('semknoxps');
        $url = $helper->semknoxRequestUrlShortener($url);

        return '"'.$url.$params.'&query="';

    }



}
