<?php
/* Copyright (C) Youbility Software - All Rights Reserved
 * www.youbility.de
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */
class Semknox_ProductSearch_Helper_Data extends Mage_Core_Helper_Abstract
{

    protected   $_credentialsStatus = array();

    public      $_currentStoreId;
    protected   $_semknoxpsIsActive;

    protected   $_allStores = false;

    /**
     * @var Varien_Io_File
     */
    protected $_fileHandler;


    public      $_changedProductsFolder = array(
        'delete' => 'semknox-delete-products',
        'update' => 'semknox-update-products'
    );


    public function __construct()
    {
        $this->_currentStoreId = $this->getCurrentStoreId();

        $this->_fileHandler = new Varien_Io_File();

    }

    /**
     * Adds entry to semknox.log
     *
     * @param string $message
     * @param integer $level
     *        const EMERG   = 0;  // Emergency: system is unusable
     *        const ALERT   = 1;  // Alert: action must be taken immediately
     *        const CRIT    = 2;  // Critical: critical conditions
     *        const ERR     = 3;  // Error: error conditions
     *        const WARN    = 4;  // Warning: warning conditions
     *        const NOTICE  = 5;  // Notice: normal but significant condition
     *        const INFO    = 6;  // Informational: informational messages
     *        const DEBUG   = 7;  // Debug: debug messages
     * @param bool $forceLog
     * @param bool $storeId
     */
    public function log($message, $level = null, $forceLog = false, $storeId = false)
    {
        if(!$storeId) $storeId = $this->_currentStoreId;

        if(is_array($message)) $message = json_encode($message);

        // add week-number to log-filename
        $date = new DateTime();
        $weekYear = $date->format("W-Y");

        $file = 'semknox.'.$weekYear.'.log';

        $dev = $this->isSandboxMode() ? '[DEV]' : '';

        $size = memory_get_usage();
        $memoryUsage =  round((memory_get_usage() / 1048576), 2 ). ' mb';

        Mage::log($dev.'[StoreID: '.$storeId.'] '.$message. ' ['.$memoryUsage.']', $level, $file, $forceLog);
    }


    public function setCurrentStoreId($storeId)
    {
        $this->_currentStoreId = $storeId;
    }

    /**
     * get Extension frontName
     *
     * @return string Extension forntName
     */
    public function getResultsUrl()
    {
        return (string) Mage::getConfig()->getNode('frontend/routers/semknoxps/args/frontName');
    }



    public function semknoxInfiniteScrollActive()
    {
        $active =  $this->getStoreConfig('semknoxps/advancedsettings/infiniteScroll',$this->_currentStoreId, 0);

        return $active > 0 ? 'true' : 'false';
    }


    public function semknoxShowInfiniteScrollButton()
    {
        $showButton =  $this->getStoreConfig('semknoxps/advancedsettings/infiniteScrollMoreButton',$this->_currentStoreId, 0);

        return $showButton > 0 ? 'true' : 'false';
    }

    public function semknoxShowSiteSearch360Results($returnAsString = false)
    {
        $storeId =  $this->_currentStoreId;

        $value = (bool) $this->getStoreConfig('semknoxps/advancedsettings/enableSiteSearch360', $storeId, false);

        if($returnAsString){
            return ($value === false) ? 'false' : 'true';
        } else {
            return $value;
        }
    }


    public function semknoxpsUniboxIsActive()
    {
        $uniboxIsActive = Mage::getStoreConfigFlag('semknoxps/unibox/active');

        return ($this->semknoxpsIsActive() && $uniboxIsActive);
    }

    /**
     * Check if the serve
     *
     * @return bool
     */
    public function semknoxpsIsActive()
    {
        if ($this->semknoxDisableSearch()) return false;

        $statusFilePath = Mage::getBaseDir('var') . DS . 'semknox' . DS . 'semknox.status';
        if(file_exists($statusFilePath) && (time() - filemtime($statusFilePath)) < 300){  // semknox status check every 5 minutes
            $status = file_get_contents($statusFilePath) == 1 ? true : false;
            $this->_semknoxpsIsActive = $status;
        } 

        if($this->_semknoxpsIsActive === true || $this->_semknoxpsIsActive === false) return $this->_semknoxpsIsActive;

        try {
            $accountManager = Mage::getModel( 'semknoxps/accountManager' );
            $accountStatus  = $accountManager->getAccountStatus();

            $this->_semknoxpsIsActive = false;

            if ( isset( $accountStatus['active'] ) ) {
                $this->_semknoxpsIsActive = $accountStatus['active'];
            }
            else if ( isset( $accountStatus['status'] ) && $accountStatus['status'] == 'SEARCH_READY' ) {
                $this->_semknoxpsIsActive = true;
            }
        }
        catch(Zend_Http_Client_Exception $e) {
            // most likely a timeout happen
            $this->log("API TIMEOUT: ". get_class());

            $this->_semknoxpsIsActive=false;
        }

        // cache status
        file_put_contents($statusFilePath, $this->_semknoxpsIsActive ? 1 : 0);

        return $this->_semknoxpsIsActive;
    }

    public function getProductListingImageWith()
    {
        $width = (int) Mage::getStoreConfig('semknoxps/advancedsettings/productListingImageWidth');
        return ($width>0) ? $width : 210;
    }

    public function getProductListingImageHeight()
    {
        $height = (int) Mage::getStoreConfig('semknoxps/advancedsettings/productListingImageHeight');
        return ($height>0) ? $height : 0;
    }


    public function showAvailableOrdersToolbarByMagento()
    {
        $option = Mage::getStoreConfig('semknoxps/advancedsettings/semknoxOrderToolbar');
        return in_array($option, array('both','magento'));
    }

    public function showAvailableOrdersToolbar()
    {
        $option = Mage::getStoreConfig('semknoxps/advancedsettings/semknoxOrderToolbar');
        return in_array($option, array('both','semknox'));
    }

    public function semknoxSeoClientSideSearchIsActive()
    {
        return Mage::getStoreConfig('semknoxps/advancedsettings/clientSideSearch');
    }

    public function semknoxSeoUrlIsActive()
    {
        return Mage::getStoreConfig('semknoxps/advancedsettings/unknowSlugToSearch');
    }

    public function semknoxSearchResultToNoIndex()
    {
        return Mage::getStoreConfig('semknoxps/advancedsettings/searchResultToNoIndex');
    }

    public function semknoxPrimaryColor()
    {
        return Mage::getStoreConfig('semknoxps/advancedsettings/primaryColor');
    }

    public function semknoxSecondaryColor()
    {
        return Mage::getStoreConfig('semknoxps/advancedsettings/secondaryColor');
    }

    public function semknoxImageCdn()
    {
        return Mage::getStoreConfig('semknoxps/advancedsettings/imageCdn');
    }

    public function semknoxFilterToggleCount()
    {
        $count = (int) Mage::getStoreConfig('semknoxps/advancedsettings/filterToggleCount');

        if(!$count) return 7;

        return $count;
    }

    public function uploadOutOfStockProducts($storeId = false)
    {
        if(!$storeId) $storeId =  $this->_currentStoreId;
        return (bool) $this->getStoreConfig('semknoxps/advancedsettings/uploadOutOfStockProducts', $storeId, false);
    }

    public function ignoreMagentoVisibilitySettings($storeId = false)
    {
        if(!$storeId) $storeId =  $this->_currentStoreId;
        return (bool) $this->getStoreConfig('semknoxps/advancedsettings/ignoreMagentoVisibilitySettings', $storeId, false);
    }

    public function semknoxDisableProductUpstream($storeId = false)
    {
        if(!$storeId) $storeId =  $this->_currentStoreId;
        return (bool) $this->getStoreConfig('semknoxps/advancedsettings/disableProductUpstream', $storeId, false);
    }

    public function semknoxDisableSearch($storeId = false)
    {
        if(!$storeId) $storeId =  $this->_currentStoreId;
        return (bool) $this->getStoreConfig('semknoxps/advancedsettings/disableSearch', $storeId, false);
    }

    public function semknoxShowQueryInterpretation()
    {
        return Mage::getStoreConfigFlag('semknoxps/advancedsettings/showQueryInterpretation');
    }

    public function semknoxPassOnAttributes($storeId = false, $fixedPassOnAttributeCodes = array())
    {
        if(!$storeId) $storeId =  $this->_currentStoreId;

        $attributesString = trim($this->getStoreConfig('semknoxps/advancedsettings/passOnAttributes', $storeId, ''));

        $attributeCodes = explode(',', $attributesString);

        $attributeCodes = array_merge($attributeCodes, $fixedPassOnAttributeCodes);

        foreach($attributeCodes as $key => $attribute)
        {
            $attributeCodes[$key] = trim($attribute);
        }

        return $attributeCodes;
    }


    /**
     * customerId of give or current store
     *
     * @param bool|false $storeId
     * @return mixed|null
     */
    public function semknoxCustomerId($storeId = false)
    {
        if(!$storeId) $storeId =  $this->_currentStoreId;
        return $this->getStoreConfig('semknoxps/login/customerId', $storeId, false);
    }

    /**
     * apiKey of given or current store
     *
     * @param bool|false $storeId
     * @return mixed|null
     */
    public function semknoxApiKey($storeId = false)
    {
        if(!$storeId) $storeId =  $this->_currentStoreId;
        return $this->getStoreConfig('semknoxps/login/apiKey', $storeId, false);
    }


    public function getSemknoxCredentialsStatus($storeId = false)
    {
        if(!$storeId) $storeId =  $this->_currentStoreId;

        if(isset($this->_credentialsStatus[$storeId])) return $this->_credentialsStatus[$storeId];

        $customerId = $this->getStoreConfig('semknoxps/login/customerId', $storeId, false);
        $apiKey = $this->getStoreConfig('semknoxps/login/apiKey', $storeId, false);

        $authStatus = 0;

        if($customerId && $apiKey)
        {
            /**
            * @var Semknox_ProductSearch_Model_AuthenticationManager $authManager
            */
            $authManager = Mage::getModel('semknoxps/authenticationManager');

            $authStatus = $authManager->checkCredentials($customerId, $apiKey);

            $authStatus = ($authStatus) ? 1 : -1;
        }

        $this->_credentialsStatus[$storeId] = $authStatus;

        return $authStatus;
    }

    public function isSandboxMode($storeId = false)
    {
        if(!$storeId) $storeId =  $this->_currentStoreId;

        $sandBoxMode = $this->getStoreConfig('semknoxps/login/sandbox', $storeId, 0);

        return (bool) $sandBoxMode;
    }

    public function semknoxCronjobIsActive()
    {
        $active = Mage::getStoreConfigFlag('semknoxps/productupload/initialUploadCronActive');

        return (bool) $active;
    }


    /**
     *
     * return last URL segment for SEO search - there its the Search query
     *
     * @return string
     */
    public function getLastDirectoryInUrl()
    {

        // remove parameters from url
        $url = strtok(Mage::helper('core/url')->getCurrentUrl(), '?');

        // get last segment without fileetxension (.html etc.)
        $urlInfo = pathinfo($url);
        $lastSegment  = isset($urlInfo['filename']) ? $urlInfo['filename'] : '';

        return $lastSegment;
    }


    /**
     * just use first 16 digits of ApiKey for public requests
     *
     * @param $url
     * @return string
     *
     */
    public function semknoxRequestUrlShortener($url)
    {
        // check if apiKey is given
        $urlParams = explode('&',$url);
        $apiKeyFound = false;

        foreach( $urlParams as $key => $param)
        {
            if(stripos($param, 'apiKey') === 0)
            {
                // if apiKey was found, shorten it and stop foreach
                $urlParams[$key] = substr($param, 0,23);
                $apiKeyFound = true;
                break;
            }
        }

        if(! $apiKeyFound) {
            $this->log('semknoxRequestUrlShortener: ApiKey not found in request url. Search / suggest will not work properly.');
        }

        // rebuild url
        $newUrl = implode('&',$urlParams);

       return $newUrl;


    }

    public function getIconByStatus($status)
    {
        switch($status){

            case 'SEARCH_READY':
                $iconCode = 'fa-check-circle-o';
                break;

            case 'PROCESSING_DATA':
                $iconCode = 'sx-fa fa-clock-o fa-spin';
                break;

            default:
                $iconCode = 'fa-question-circle-o';
                break;
        }

        return $iconCode;
    }

    public function getCurrentStoreId()
    {
        if($storeId = Mage::app()->getRequest()->getParam('storeid')) {
            return $storeId;
        }

        if(Mage::app()->getStore()->isAdmin())
        {
            if (strlen($code = Mage::getSingleton('adminhtml/config_data')->getStore())) // store level
            {
                $storeId = Mage::getModel('core/store')->load($code)->getId();
            } elseif (strlen($code = Mage::getSingleton('adminhtml/config_data')->getWebsite())) // website level
            {
                $website_id = Mage::getModel('core/website')->load($code)->getId();
                $storeId    = Mage::app()->getWebsite($website_id)->getDefaultStore()->getId();
            } else // default level
            {
                $storeId = 0;
            }
        }
        else
        {
            $storeId = Mage::app()->getStore()->getStoreId();
        }

        return $storeId;
    }

    public function getStoreConfig($node, $storeId, $default = null )
    {
        $value = Mage::getStoreConfig($node, $storeId);

        if($default && ($value == null || empty($value)))
        {
            $value = $default;
        }

        return $value;

    }

    public function setCurrentWizardStep($step, $storeId)
    {

        if($step > 5) $step = 5;

        Mage::getModel('core/config')->saveConfig('semknoxps_wizard/general/currentStep', $step, 'stores', $storeId);
        Mage::app()->getStore($storeId)->resetConfig();
    }


    /**
     * returns an array of all stores, each elements key is the storeId and the value an array of 'isDefault' and 'code'
     *
     * @return array $stores
     */
    public function getAllStores()
    {
        if(is_array($this->_allStores)) return $this->_allStores;

        $stores = array();

        $websites = Mage::app()->getWebsites();

        foreach($websites as $website)
        {
            $defaultStoreId = false;

            if($defaultStore = $website->getDefaultStore()) {
                $defaultStoreId = $defaultStore->getId();
            }

            foreach ($website->getGroups() as $group) {

                $groupStores = $group->getStores();

                foreach ($groupStores as $groupStore) {

                    $storeId = $groupStore->getId();
                    $isDefault = ($defaultStoreId && $defaultStoreId == $storeId);

                    $stores[$storeId] = array(
                        'isDefault'   => $isDefault,
                        'code'      => $groupStore->getCode()
                    );
                }
            }
        }

        return $stores;
    }

    /**
     * returns an array of all stores that have api credentials, each elements key is the storeId and the value an array of 'isDefault','code','apiKey' and 'customerId'
     *
     * @return array $stores
     */
    public function getAllStoresCredentials()
    {
        $stores = $this->getAllStores();

        foreach($stores as $storeId => $store)
        {
            $apiKey = $this->semknoxApiKey($storeId);
            $customerId = $this->semknoxCustomerId($storeId);

            if($customerId && $apiKey)
            {
                $store['apiKey'] = $apiKey;
                $store['customerId'] = $customerId;
                $stores[$storeId] = $store;

            } else {
                unset($stores[$storeId]);
            }
        }

        return $stores;
    }


    public function addProductToUpdateQueue($productId, $action = 'update')
    {
        $action = ( in_array($action, array('update','delete')) ) ? $action : 'update';

        $folder = $this->_changedProductsFolder[$action];
        $filename = $productId;
        $status = $this->_createFile($folder, $filename);


        // remove file if exists in other action
        $oppositeAction = ($action == 'update') ? 'delete' : 'update';
        $folder = $this->_changedProductsFolder[$oppositeAction];
        $this->_removeFile($folder, $filename);


        return $status;
    }


    protected function _createFile($folder, $filename)
    {
        $folder = Mage::getBaseDir('var') . DS . $folder;
        $file = $folder. DS . $filename;

        //check if folder exists
        if(!$this->_fileHandler->fileExists($folder, false)){
            @$this->_fileHandler->mkdir($folder, 0777, true);
        }

        return @$this->_fileHandler->write($file, ' ', 0777);

    }

    protected function _removeFile($folder, $filename)
    {
        $folder = Mage::getBaseDir('var') . DS . $folder;
        $file = $folder. DS . $filename;

        if($this->_fileHandler->fileExists($file, true)){
            @$this->_fileHandler->rm($file);
        }

    }

    public function removeProductFromUpdateQueue($productId)
    {
        foreach($this->_changedProductsFolder as $folder){
            $this->_removeFile($folder, $productId);
        }
    }

    public function getCurrentUsersGroup()
    {
        $customerSession = Mage::getSingleton('customer/session');

        if($customerSession->isLoggedIn()){
            $customerGroupId = $customerSession->getCustomerGroupId();
        } else {
            $customerGroupId = 'all';
        }

        return $customerGroupId;
    }

}
