<?php
/* Copyright (C) Youbility Software - All Rights Reserved
 * www.youbility.de
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */
class Semknox_ProductSearch_Helper_ProductTransformer extends Mage_Core_Helper_Abstract
{
    protected $_currency;

    protected $_currentStoreId;

    protected $_helper;

    protected $_imageCDN;

    protected $_productsAlreadyLoaded = array();

    protected $_fixedPassOnAttributeCodes = array('visibility');

    protected $_magentoUserGroups = array();

    public function __construct($storeId=null)
    {
        if($storeId)
        {
            $currentStore = Mage::getModel('core/store')->load($storeId);
            $this->_currentStoreId = $storeId;
        } else {
            $currentStore = Mage::app()->getStore();
            $this->_currentStoreId = $currentStore->getStoreId();
        }

        $this->_currency =  $currentStore->getCurrentCurrencyCode();
        $this->_helper = Mage::helper('semknoxps');
        $this->_helper->setCurrentStoreId = $this->_currentStoreId;

        $this->_passOnAttributes = array();

        $this->_imageCDN = false;
        if($this->_helper->semknoxImageCdn() && strlen($this->_helper->semknoxImageCdn()) > 5){
            $this->_imageCDN = $this->_helper->semknoxImageCdn();
        }

        foreach(Mage::getModel('customer/group')->getCollection() as $userGroup){
            $this->_magentoUserGroups[] = $userGroup->getCustomerGroupId();
        }

    }

    public function init()
    {
        $this->_passOnAttributes = $this->_helper->semknoxPassOnAttributes($this->_currentStoreId, $this->_fixedPassOnAttributeCodes);
    }

    /**
     * the storeId of the current process
     *
     * @param $storeId
     */
    public function setCurrentStoreId($storeId)
    {
        $this->_currentStoreId = $storeId;
    }

    public function toApi(Mage_Catalog_Model_Product $product)
    {
        $data = array();

        // check if product is not visible, but part of a configurable product
        $data = $this->_productBelongsToGroup($product, $data);
        if(isset($data['remove']))
        {
            return false;
        }

        // make product data
        $url =  isset($data['link']) ? $data['link'] : $this->_getProductUrl($product);
        $productId = $product->getId();

        $product = Mage::getModel('catalog/product')->setStoreId($this->_currentStoreId)->load($productId);

        $cleanProductAttributes = $product->getAttributes();
        $productStockData = $product->getStockItem()->getData();

        $price = $this->_getProductPrice($product);

        $data['name'         ] = $product->getName() ?: '';
        $data['articleNumber'] = $productId;
        $data['price'        ] = $this->_formatPrice($price);
        $data['description'  ] = $this->_getProductDescription($product, $data);
        $data['deeplink'     ] = $url;
        $data['link'         ] = $url;
        $data['attributes'   ] = $this->_getAttributes($product, $cleanProductAttributes, $productStockData);
        $data['image'        ] = $this->_getMainProductImage($product, $data);
        $data['category'     ] = $this->_getCategoryName($product);
        $data['passOn'       ] = array('storeId' => $this->_currentStoreId);

        // add groupAttributes
        $data = $this->_addUserGroupAttributes($data, $product);

        // add custom passOn
        if(!empty($this->_passOnAttributes))
        {
            foreach($this->_passOnAttributes as $attributeCode)
            {
                if(isset($cleanProductAttributes[$attributeCode]) && $value = $cleanProductAttributes[$attributeCode]->getFrontend()->getValue($product))
                {
                    if($attributeCode == 'visibility')
                    {
                        /*
                        const VISIBILITY_NOT_VISIBLE    = 1;
                        const VISIBILITY_IN_CATALOG     = 2;
                        const VISIBILITY_IN_SEARCH      = 3;
                        const VISIBILITY_BOTH           = 4;
                        */

                        $value = ($this->_getProductVisibility($product) > 2) ? 1 : 0;

                        // new visible_in_search attribute
                        $data['passOn']['visible_in_search'] = $value;
                    }

                    // if someone still uses the old attribute:
                    $data['passOn'][$attributeCode] = $value;

                } else if(isset($productStockData[$attributeCode]))
                {
                    $data['passOn'][$attributeCode] = $productStockData[$attributeCode];
                }
            }
        }

        // add Ratings to passOn
        if(isset($data['attributes']['Bewertungen']) && $data['attributes']['Bewertungen'])
        {
            $data['passOn']['reviews_count'] = $data['attributes']['Bewertungen'];
            $data['passOn']['rating'] = $data['attributes']['Bewertung'];
        }

        // wenn nur das konfigurierbare Produkt sichtbar ist, aber description aus den simple products kommen
        //$data = $this->_modifyConfigurableProductsDataIfConsistsOfSimpleProducts($product, $data);

        //todo: fix description transformation in attributes node (destroys json sometimes)
        //$data['attributes']['Description sxNotVisible'] = $data['description'];
        //unset( $data['attributes']['Short Description sxNotVisible']);

        return $data;
    }


    /**
     * @param $product
     * @param $data
     * @return mixed
     */
    protected function _modifyConfigurableProductsDataIfConsistsOfSimpleProducts($product, $data)
    {
        if($product->getTypeId() != 'configurable' || strlen($data['description']) > 0) return $data;

        // @codingStandardsIgnoreStart
        $firstChild = $product->getTypeInstance()
                     ->getUsedProductCollection()
                     ->addAttributeToSelect('description')
                     ->setPageSize(1)
                     ->getFirstItem();
        // @codingStandardsIgnoreEnd

        if($firstChild && $childDescription = $firstChild->getDescription())
        {
            $data['description'] = $childDescription;
        }

        return $data;

    }

    /**
     * Description of the Product
     *
     * @param $product
     * @param $data
     * @return string
     */
    protected function _getProductDescription($product, $data)
    {
        $description = $product->getDescription();

        $simpleProduct = !in_array($product->getTypeId(), array('configurable', 'grouped'));
        $parentId = (isset($data['groupId'])) ? $data['groupId'] : false;
        $descriptionEmpty = !$description || !strlen($description);

        // if description of simple product is empty, check for parents description
        if($simpleProduct && $parentId && $descriptionEmpty)
        {
            $parent = $this->_getCachedProduct($parentId);
            $description = $parent->getDescription();
        }
        // if description of configurable product is empty, check for first childs description
        else if($product->getTypeId() == 'configurable' && $descriptionEmpty)
        {
            // @codingStandardsIgnoreStart
            $firstChild = $product->getTypeInstance()
                                  ->getUsedProductCollection()
                                  ->addAttributeToSelect('description')
                                  ->setPageSize(1)
                                  ->getFirstItem();
            // @codingStandardsIgnoreEnd

            if($firstChild && $childDescription = $firstChild->getDescription())
            {
                $description = $childDescription;
            }
        }

        return $description;
    }


    protected function _getCachedProduct($productId)
    {
        if(!isset($this->_productsAlreadyLoaded[$productId]))
        {
            $product = Mage::getModel('catalog/product')->setStoreId($this->_currentStoreId)->load($productId);
            $this->_productsAlreadyLoaded[$productId] = $product;
        }

        return $this->_productsAlreadyLoaded[$productId];
    }


    protected function _getProductVisibility($product, $ignoreExtensionSettings = true)
    {
        // visibility:
        //  1 => not visible, 2 => in catalog, 3 => in search, 4 => both
        $visibility = $product->getVisibility();

        if($ignoreExtensionSettings)
        {
            return $visibility;
        }

        // if set in Backend settings, all product (bundled, configurable) will be set visible in search.
        if($this->_helper->ignoreMagentoVisibilitySettings($this->_currentStoreId)){
            return 4;
        } else {
            return $visibility;
        }

    }


    /**
     * adds groupId Key to data-array if Product belongs to a Semknox Productgroup
     *
     * @param $product
     * @param $data
     * @return array
     */
    protected function _productBelongsToGroup($product,$data)
    {
        $data = array();

        /*
         * const TYPE_SIMPLE       = 'simple';
         * const TYPE_BUNDLE       = 'bundle';
         * const TYPE_CONFIGURABLE = 'configurable';
         * const TYPE_GROUPED      = 'grouped';
         * const TYPE_VIRTUAL      = 'virtual';
         */

        // each configurable/grouped Product belongs to it's group
        if(in_array($product->getTypeId(), array('configurable', 'grouped')))
        {
            $data['groupId'] = $product->getId();


            if($this->_getProductVisibility($product, false) <= 2) // not visible in search
            {
                $data['remove'] = true;
                return $data;
            }

            return $data;
        }

        $parentId = false;

        // visibility:
        //  1 => not visible, 2 => in catalog, 3 => in search, 4 => both

        if($this->_getProductVisibility($product, false) <= 2)
        {
            // simple products who are INVISIBLE and are part of a configurable product GET A groupId
            // -> because they will not be shown in listing, but get merged

            if($parentId = $this->_getParentId($product))
            {
                $parent = $this->_getCachedProduct($parentId);

                $url = $this->_getProductUrl($parent);

                // add groupId
                $data['groupId'] = $parentId;
                $data['link'] = $url;

            } else {
                // remove product form batch (set 'remove')
                $data['remove'] = true;
                return $data;
            }
        }
        // visible simple products DO NOT get a groupId (because they have to be shown as single product in listing)

        return $data;
    }

    /**
     * parent Id of a Product; FALSE if Product does not have a parent
     *
     * @param $product
     * @return mixed
     */
    protected function _getParentId($product)
    {
        $parentIds = Mage::getModel('catalog/product_type_configurable')->getParentIdsByChild($product->getId());
        if(!$parentIds) {
            $parentIds = Mage::getModel('catalog/product_type_grouped')->getParentIdsByChild($product->getId());
        }

        if(isset($parentIds[0])) {
            return $parentIds[0];
        }

        return false;
    }


    /**
     * category of a product
     *
     * @param $product
     * @return string
     */
    protected function _getCategoryName($product)
    {
        // get category ids and name of first cat id
        $categoryNames = array();
        $categoryIds = $product->getCategoryIds();

        if(count($categoryIds) ){

            $paths = array();

            foreach($categoryIds as $catId)
            {
                $currentPath = array();

                $parentPath = Mage::getResourceModel('catalog/category')->getAttributeRawValue($catId, 'path',$this->_currentStoreId);

                $parentPath = explode('/', $parentPath);
                $parentPath = array_splice($parentPath, 2);

                foreach ($parentPath as $parentId):
                    $currentPath[] = $this->escapeHtml(Mage::getResourceModel('catalog/category')->getAttributeRawValue($parentId, 'name',$this->_currentStoreId));
                endforeach;

                $paths[] =  $currentPath;
            }

            // get deepest path
            $thePath = array();
            foreach($paths as $path)
            {
                $thePath = (count($path) > count($thePath)) ? $path : $thePath;
            }

            return join('#', $thePath);

            /*
            $categoryCollection = Mage::getResourceModel('catalog/category_collection')
                ->setStoreId($this->_currentStoreId)
                ->addAttributeToSelect('name')
                ->addAttributeToFilter('entity_id', $categoryIds)
                ->addIsActiveFilter();

            foreach($categoryCollection as $category){
                $categoryNames[] = $category->getName();
            }

            return join('#', $categoryNames);
            */
        }
        else {
            return '';
        }

    }

    /**
     * Get all attributes for the current product
     * @param $product Mage_Catalog_Model_Product
     *
     * @return array
     */
    protected function _getAttributes($product, $cleanProductAttributes, $productStockData)
    {
        $result = array();
        $attributes = $cleanProductAttributes;

        foreach ($attributes as $attributeName => $attribute) {

            if($attributeName == 'price') continue;

            /**
             * Since: 2016-04-08: all Product Attributes will be send to Semknox... none visible will be marked as sxNotVisible
             */

            //if($this->shouldAttributeBeUploaded($attributeName, $attribute)) {

                /* @var $attribute Mage_Eav_Model_Attribute */
                $key   = $attributeName;

                $attribute->setStoreId($this->_currentStoreId);
                $value = $attribute->getFrontend()->getValue($product);

                // add to result
                if($value) {

                    $valueArray = $this->_prepareAttributeValueArray($value);

                    $visible = $this->_shouldAttributeBeUploaded($attributeName, $attribute);
                    //$storeLabel = ($attribute->getStoreLabel()) ? $attribute->getStoreLabel() : '';
                    $storeLabel = ($attribute->getStoreLabel($this->_currentStoreId)) ? $attribute->getStoreLabel($this->_currentStoreId) : '';


                    foreach($valueArray as $idx => $value)
                    {
                        $resultAttribute['value'] = $value;
                        $resultAttribute['storeLabel'] = $storeLabel;
                        $resultAttribute['visible'] = $visible;
                        $resultAttribute['key'] = $key;
                        $resultAttribute['idx'] = $idx;

                        $result[$key.$idx] = $resultAttribute;
                    }

                }
            //}
        }

        $result = $this->_addProductStockData($result, $productStockData);

        $result = $this->_translateAttributeKeys($result);

        $result = $this->_addProductRating($result, $product);


        if($product->getFinalPrice() && $product->getPrice() && $product->getFinalPrice() < $product->getPrice())
        {
            $result['on_discount'] = 1;
        } else {
            $result['on_discount'] = 0;
        }


        return $result;
    }


    protected function _shouldAttributeBeUploaded($attributeName, $attribute)
    {
        $allowedAttributeNames = $this->_additionallyAllowedAttributeCodes();

        return $attribute->getIsVisibleOnFront() or in_array($attributeName, $allowedAttributeNames) ;
    }


    /**
     * add product rating notes to given product attribute array
     *
     * @param $attributes
     * @param $product
     */
    protected function _addProductRating($attributes, $product)
    {
        if(version_compare(Mage::getVersion(), '1.10.0.0') >= 0) return $attributes;
        // disable for EE .. ALL CE are < 1.2 (example: 1.9);
        
        $reviewsData = Mage::getModel('review/review_summary')
                        ->setStoreId($this->_currentStoreId)
                        ->load($product->getId());


        if($reviewsData && !empty($reviewsData))
        {
            $attributes['Bewertungen'] = $reviewsData['reviews_count'];
            $attributes['Bewertung'] = $reviewsData['rating_summary'];
        }

        return $attributes;
    }

    /**
     * add product availability to given product attribute array
     *
     * @param $attributes
     * @param $product
     */
    protected function _addProductStockData($result, $productStockData)
    {
        if(!$productStockData) return $result;

        foreach($productStockData as $attributesName => $attribute){

            $resultAttribute['value'] = $attribute;
            $resultAttribute['storeLabel'] = null;
            $resultAttribute['visible'] = false;
            $resultAttribute['key'] = $attributesName;
            $resultAttribute['idx'] = 0;

            $result[$attributesName] = $resultAttribute;
        }

        return $result;
    }

    /**
     * Returns Array with all aditionally allowed Attributes
     * @param $value
     * @return array
     */
    protected function _additionallyAllowedAttributeCodes()
    {
        //$allowedAttributeNamesFromBackend = Mage::getStoreConfig('semknoxps/advancedsettings/attributesAllowed');
        //$allowedAttributeNamesFromBackend = explode(',',$allowedAttributeNamesFromBackend);
        $allowedAttributeNamesFromBackend = array();

        $allowedAttributeNames = array_merge(array('sku', 'manufacturer', 'brand'),$allowedAttributeNamesFromBackend);

        return $allowedAttributeNames;
    }



    protected function _prepareAttributeValueArray($value)
    {
        if(is_array($value)) return array();

        $valueArray = preg_split('/<br[^>]*>/i', $value);

        if(!is_array($valueArray)) $valueArray[] = $value;

        return $valueArray;
    }


    /**
     * Change the key to be matchable.
     *    size  => Größe
     *    color => Farbe
     * @param $key
     */
    protected function _translateAttributeKeys($attributes)
    {
        $matching = Mage::getStoreConfig('semknoxps/advancedsettings/attributeMatch');
        $matchingRaw = unserialize($matching);
        $matching = array();

        foreach((array) $matchingRaw as $data) $matching[$data['magento']] = $data['api'];
        // matchin[attribute_code] = api_code;

        $sxNotVisible = array();
        $sxVisible = array();

        foreach($attributes as $k => $value)
        {
            $code = $value['key'];
            $attribute_code = $code;

            // is set in matching table?
            if(isset($matching[$attribute_code])) {

                $code = $matching[$attribute_code];
            }
            // is translated via viewName?
            else if(strlen($value['storeLabel'])){

                $code = $value['storeLabel'];
            }

            $code .= ($value['idx'] > 0) ? ' '.($value['idx'] + 1) : '';

            if(isset($value['visible']) && $value['visible'] === false)
            {
                $sxNotVisible[$code. ' sxNotVisible'] = $value['value'];
            } else {
                $sxVisible[$code] = $value['value'];
            }
        }

        $result = array_merge($sxVisible, $sxNotVisible);

        return $result;
    }

    /**
     * Get the first image
     * @param $product
     *
     * @return string
     */
    protected function _getMainProductImage($product, $data = array())
    {

        try {

            $width = $this->_helper->getProductListingImageWith();
            $height = $this->_helper->getProductListingImageHeight();

            if($height > 0)
            {
                $image = (string) Mage::helper('catalog/image')->init($product, 'small_image')->resize($width, $height);
            } else {
                $image = (string) Mage::helper('catalog/image')->init($product, 'small_image')->resize($width);
            }

            // add uncached image if cached Image was not available // fallback
            /*
            if(stripos($image, '/placeholder/') !== false && isset($data['attributes']['Small Image sxNotVisible']) && strlen($data['attributes']['Small Image sxNotVisible']) > 0){
                $image = Mage::getBaseUrl(Mage_Core_Model_Store::URL_TYPE_MEDIA) . 'catalog/product'.$data['attributes']['Small Image sxNotVisible'];
            }
            */

            $image = $this->_addImageCDN($image);
        }
        catch(Exception $e) {
            $image = '';
        }

        return $image;

    }

    protected function _addImageCDN($image)
    {
        if($this->_imageCDN)
        {
            $image = explode('/media/', $image, 2);

            if(count($image) == 2) $image[0] = $this->_imageCDN;

            $image = implode('/media/', $image);
        }

        return $image;
    }

    protected function _getProductUrl($product)
    {
        // Old Version:
        //$productSlug = $product->getUrlPath();

        Mage::app()->setCurrentStore($this->_currentStoreId);
        $productSlug = Mage::helper('catalog/product')->getProductUrl($product->getId());

        if( empty($productSlug) )
        {
            $productSlug = Mage::getBaseUrl(Mage_Core_Model_Store::URL_TYPE_WEB);
            $productSlug .= Mage::getModel('catalog/product_url')->formatUrlKey($product->getName());
        }

        return $productSlug;
    }

    protected function _getProductPrice($product)
    {
        $taxHelper = Mage::helper('tax');
        $productType = $product->getTypeId();
        $price = 0;

        switch($productType){

            // bundle product
            case 'bundle':
                $price = Mage::getModel('bundle/product_price')->getTotalPrices($product,'min',1);
                break;

            // grouped product
            case 'grouped':
                $_associatedProducts = $product->getTypeInstance(true)->getAssociatedProducts($product);
                foreach ($_associatedProducts as $child) {
                    $childPrice = $child->getFinalPrice();
                    if($price <= 0 || $childPrice < $price)
                    {
                        $price = $childPrice;
                    }
                }
                break;

            // configurable product
            case 'configurable':
                //get all configurable attributes
                $attributes = $product->getTypeInstance(true)->getConfigurableAttributes($product);
                //array to keep the price differences for each attribute value
                $pricesByAttributeValues = array();
                //base price of the configurable product
                $basePrice = $product->getFinalPrice();
                //loop through the attributes and get the price adjustments specified in the configurable product admin page
                foreach ($attributes as $attribute){
                    $prices = $attribute->getPrices();
                    foreach ($prices as $price){
                        if ($price['is_percent']){ //if the price is specified in percents
                            $pricesByAttributeValues[$price['value_index']] = (float)$price['pricing_value'] * $basePrice / 100;
                        }
                        else { //if the price is absolute value
                            $pricesByAttributeValues[$price['value_index']] = (float)$price['pricing_value'];
                        }
                    }
                }

                //get all simple products
                $simple = $product->getTypeInstance()->getUsedProducts();
                //loop through the products
                foreach ($simple as $sProduct){
                    $totalPrice = $basePrice;
                    //loop through the configurable attributes
                    foreach ($attributes as $attribute){
                        //get the value for a specific attribute for a simple product
                        $value = $sProduct->getData($attribute->getProductAttribute()->getAttributeCode());
                        //add the price adjustment to the total price of the simple product
                        if (isset($pricesByAttributeValues[$value])){
                            $totalPrice += $pricesByAttributeValues[$value];
                        }
                    }

                    if($price <= 0 || $totalPrice < $price)
                    {
                        $price = $totalPrice;
                    }
                }
                break;

            // simple/virtual/downloadable product
            default:
                $price = $product->getFinalPrice();
                break;
        }

        $price = $taxHelper->getPrice($product, $price, true, null, null, null, $this->_currentStoreId);


        //check Price Rules
        $discounted_price = Mage::getModel('catalogrule/rule')->calcProductPriceRule($product
            ->setStoreId($this->_currentStoreId)
            ->setCustomerGroupId(0),
            $product->getPrice()
        );
        if($discounted_price){
            $price = $discounted_price;
        }


        return $price;

    }


    protected function _addUserGroupAttributes($data, $product){

        $data['excludeUserGroups'] = array();

        $data['includeUserGroups'] = $this->_magentoUserGroups;
        $data['includeUserGroups'][] = 'all';

        // check for individuell group prices
        $groupPrices = $product->getData('group_price');
        if (is_array($groupPrices) && !empty($groupPrices)) {

            foreach($groupPrices as $group){

                $groupId = $group['cust_group'];
                $groupPrice = $group['price'];

                $data['userGroupAttributes'][$groupId] = array(
                    'key'   => 'price',
                    'value' => $this->_formatPrice($groupPrice)
                );
            }
        }

        // get discount prices by price-rule (if exists)
        foreach($this->_magentoUserGroups as $groupId){

            $discounted_price = Mage::getModel('catalogrule/rule')->calcProductPriceRule($product
                ->setStoreId($this->_currentStoreId)
                ->setCustomerGroupId($groupId),
                $product->getPrice()
            );

            if(isset($discounted_price)){

                $data['userGroupAttributes'][$groupId] = array(
                    'key'   => 'price',
                    'value' =>  $this->_formatPrice($discounted_price)
                );
            }

        }

        return $data;

    }

    protected function _formatPrice($price){

        $price = number_format($price , 2, ',', '.');
        $price .= ' ' . $this->_currency;

        return $price;
    }

}