<?php
/* Copyright (C) Youbility Software - All Rights Reserved
 * www.youbility.de
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */

class Semknox_ProductSearch_AjaxController extends Mage_Core_Controller_Front_Action
{

    public function compareUrlAction()
    {
        $this->_addProductTo('compare');
    }

    public function wishlistUrlAction()
    {
        $this->_addProductTo('wishlist');
    }

    public function addToCartUrlAction()
    {
        $this->_addProductTo('cart');
    }


    /**
     * retuns URL to Product Action add to wishlist/comparelist/cart
     *
     * @param $type
     * @return bool
     */
    protected function _addProductTo($type)
    {
        // get given ProductId
        $product_id = Mage::app()->getRequest()->getParam('productId', false);
        if(!$product_id) return false;

        // get Product
        $product = Mage::getModel('catalog/product')->load($product_id);
        if(!$product) $type = false;


        $return = array();
        $redirectUrl = false;

        // decide what Action Url we need
        switch($type){

            case 'wishlist':
                $redirectUrl = Mage::helper('wishlist')->getAddUrl($product);
                break;

            case 'compare':
                $redirectUrl = Mage::helper('catalog/product_compare')->getAddUrl($product);
                break;

            case 'cart':
                $redirectUrl = Mage::helper('checkout/cart')->getAddUrl($product);
                break;

            default:
                break;
        }

        // if getting Action Url was succesfully, return
        if($redirectUrl)
        {
            $return  = array(
                'redirectUrl' => $redirectUrl
            );
        }

        // output as json
        $this->getResponse()->clearHeaders()->setHeader('Content-type','application/json',true);
        $this->getResponse()->setBody(json_encode($return));

    }


    public function getProductImagesAction()
    {
        // get give ProductId
        $product_ids = Mage::app()->getRequest()->getParam('productIds', false);
        if(!$product_ids) return false;

        if(!is_array($product_ids))
        {
            $product_ids = array((int) $product_ids);
        }

        $width = Mage::app()->getRequest()->getParam('width', false);
        if(!$width) return false;

        $height = (int) Mage::app()->getRequest()->getParam('height', 0);

        // get give ProductId
        $type = Mage::app()->getRequest()->getParam('type', 'image');

        //also excluded image
        $includeExcluded = Mage::app()->getRequest()->getParam('excluded', 0);

        $products = array();
        foreach($product_ids as $product_id)
        {
            $product = Mage::getModel('catalog/product')->load((int) $product_id);

            if($includeExcluded > 0)
            {
                $gallery_images = $product->getMediaGallery('images');
            } else {
                $gallery_images = $product->getMediaGalleryImages();
            }

            $images = array();
            foreach($gallery_images as $key => $image) {

                if($includeExcluded > 0)
                {
                    $images[$key] = $image;
                    $file = $image['file'];
                } else {
                    $images[$key] = $image->toArray();
                    $file = $image->getFile();
                }

                if(!$height || $height <= 0)
                {
                    $images[$key]['resized'] = (string) Mage::helper('catalog/image')->init($product, $type, $file)->resize((int)  $width);
                } else {
                    $images[$key]['resized'] = (string) Mage::helper('catalog/image')->init($product, $type, $file)->resize((int)  $width, (int) $height);
                }

            }

            if(empty($images))
            {
                if(!$height || $height <= 0) {
                    $images[0]['resized'] = (string)Mage::helper('catalog/image')->init(Mage::getModel('catalog/product'), $type)->resize((int)  $width);
                } else {
                    $images[0]['resized'] = (string)Mage::helper('catalog/image')->init(Mage::getModel('catalog/product'), $type)->resize((int)  $width, (int) $height);
                }
            }

            $products[$product_id] = $images;

        }

        // output as json
        $this->getResponse()->clearHeaders()->setHeader('Content-type','application/json',true);
        $this->getResponse()->setBody(json_encode($products));

    }

}