jQuery(document).ready(function($) {

    var ready = false, isWizard = false;
    var pause = true;

    var storeId =  $('[data-storeid]').data('storeid');

    // get/check store id
    if(!storeId) {
        console.warn("SEMKNOX: No storeId found: if you are in a store-Action, element with data-storeid should exist in source.")
        // stop script
        return;
    }

    if($('.sx-wizzard').length)
    {
        isWizard = true;
    }

    var allButtons;

    var $buttonElement = getButtonElement();
    var $progressBarElement = getProgressBarElement();

    var $urls = {
        upload:  sxExtensionConfig.urls.upload.start,
        check:   sxExtensionConfig.urls.upload.check,
        cancel:  sxExtensionConfig.urls.upload.cancel,
        setstep: sxExtensionConfig.urls.upload.wizardsetstep
    };

    // check Status
    checkUploadStatus();
    setInterval(checkUploadStatus,3000);


    function getButtonElement(){

        var $elem = $('button[name=initialupload] span span span');

        $('button[name=initialupload]').addClass('disabled');

        var $elemCancel = $('');
        if(!isWizard){
            $('button[name=initialupload]').after(' <button type="button" class="cancelButton" onclick="var event=new CustomEvent(\'cancelInitialProductUpload\', {detail:{sender:this}});document.dispatchEvent(event);">Stop</button>');

            $elemCancel = $('button.cancelButton');
        }

        allButtons = $('#semknoxps_productupload button, .sx-pause-button-container button');
        allButtons.addClass('disabled');

        allButtons.removeAttr('title');

        return {
            labelStart :    $elem.html(),
            labelContinue : $elem.find('span.continue').text(),
            labelPause :    $elem.find('span.pause').text(),
            elemCancel:     $elemCancel,
            elem :          $('button[name=initialupload]')
            };
    }

    function getProgressBarElement() {
        // find progress container
        var $elem = $('.sx-progress-container');

        if ($elem.size() == 0) {
            $elem = $('<p class="sx-progress-action"></p><div class="sx-progress-container"><div class="sx-progress-bar" style="width:0%"></div><span class="sx-progress-label"></span></div>');

            // insert element
            allButtons.last().after($elem.hide());
        }


        if (isWizard) {
            $('button[name=initialupload]').before('<p class="sx-last-complete-message"></p>');
        } else {
            $('label[for=semknoxps_productupload_initialUpload]').after('<p class="sx-last-complete-message"></p>');
        }

        var $progressBar        = $elem.find('.sx-progress-bar');
        var $progressMessage    = $('div.sx-progress-message');
        var $progressLabel      = $elem.find('.sx-progress-label');
        var $progressAction     = $('.sx-progress-action');
        var $lastElem           = $('p.sx-last-complete-message');


        return {
            bar:        $progressBar,
            label:      $progressLabel,
            message:    $progressMessage,
            action:     $progressAction,
            elem:       $elem,
            lastElem:   $lastElem
        }
    }

    /**
     * Listen for "startInitialProductUpload" event. Despite the name,
     * this event either starts or stops the product upload
     */
    $(document).on('startInitialProductUpload', function(event)
    {
        if(!ready){
            console.warn('not ready... try again.')
            return;
        }

        if(!pause) {
            pauseUpload();
        } else {
            startUpload(event);
        }

        ready = false;
        allButtons.addClass('disabled');
    });


    /**
     * Listen for "cancelInitialProductUpload" event.
     */
    $(document).on('cancelInitialProductUpload', function(event)
    {
        if(!ready){
            console.warn('not ready... try again.')
            return;
        }

        cancelUpload();

        ready = false;
        allButtons.addClass('disabled');
    });


    /**
     * Start or continue the product upload
     */
    function startUpload(event)
    {
        $.getJSON($urls.upload, {storeid: storeId, startedby: 'cron', pause: false}, function(response)
        {})
    }

    /**
     * pause the product upload
     */
    function pauseUpload(event)
    {
        $.getJSON($urls.upload, {storeid: storeId, startedby: 'cron', pause: true}, function(response)
        {})
    }

    /**
     * cancel current product upload
     */
    function cancelUpload(event)
    {
        $.getJSON($urls.cancel, {storeid: storeId}, function(response)
        {})
    }


    function checkUploadStatus()
    {
        // check current store id
        $.getJSON($urls.check, {storeid: storeId, startedby: 'cron'}, function($response)
        {
            refreshGui($response);

            pause = $response.pause;
            ready = true;
            allButtons.removeClass('disabled');
        });

    }


    function refreshGui($response){

        var message = '';

        if($response.status == 'pending') {

            $buttonElement.elem.html($buttonElement.labelStart);

            $progressBarElement.elem.hide();

            $progressBarElement.message.hide();
            $progressBarElement.action.html('');

            $buttonElement.elemCancel.hide();

            $('input#semknoxps_advancedsettings_readBatchSize').removeAttr('disabled').removeClass('disabled');
            $('input#semknoxps_advancedsettings_sendBatchSize').removeAttr('disabled').removeClass('disabled');
            $('select#semknoxps_advancedsettings_ignoreMagentoVisibilitySettings').removeAttr('disabled').removeClass('disabled');

        } else {

            $('input#semknoxps_advancedsettings_readBatchSize').attr('disabled','disabled').addClass('disabled');
            $('input#semknoxps_advancedsettings_sendBatchSize').attr('disabled','disabled').addClass('disabled');
            $('select#semknoxps_advancedsettings_ignoreMagentoVisibilitySettings').attr('disabled','disabled').addClass('disabled');

            $buttonElement.elemCancel.show();

            if ($response.status == 'collecting') {

                $buttonElement.elem.html($buttonElement.labelPause);

            } else if ($response.status == 'uploading' || $response.status == 'after_product_work') {

                $buttonElement.elem.html($buttonElement.labelPause);
            }

            // set progress bar
            $progressBarElement.elem.show();

            var percentage = $response.percentage;

            $progressBarElement.label.text(percentage + ' %');
            $progressBarElement.bar.css('width', percentage + '%');
            $progressBarElement.bar.prop('Percent', percentage);

            if(Math.ceil(percentage) >= 52){
                $progressBarElement.label.addClass('sx-percentage-white');
            } else {
                $progressBarElement.label.removeClass('sx-percentage-white');
            }

            // set message
            message += '<b>Details:</b><p>';
            for (var property in $response) {
                message += property + ': ' + $response[property]+'<br>';
            }
            message += '</p>';

            $progressBarElement.message.show();


            // check if pause
            var pauseInfo = '<b style="color: black">PAUSE</b> ';
            if($response.pause)
            {
                $progressBarElement.bar.addClass('pause');
                $buttonElement.elem.html($buttonElement.labelContinue);

            } else {
                pauseInfo = '';
                $progressBarElement.bar.removeClass('pause');
            }

            // view current Action
            $progressBarElement.action.html(pauseInfo + '<b>' + $response.currentStep + '/' + $response.stepQty + '</b> ' + $response.status + '...');

        }


        if($response.last)
        {
            message += '<b>Details of last Upload:</b><p>';
            for (var property in $response.last) {
                message += property + ': ' + $response.last[property]+'<br>';
            }
            message += '</p>';

            $progressBarElement.message.show();

            $progressBarElement.lastElem.html('<br><b>Letzte Ausführung</b><br>Zeitpunkt: ' + $response.last['endTime'] + '<br>Dauer: ' + $response.last['duration']);
        }


        if(!isWizard) {
            $progressBarElement.message.html(message);
        }


        // check for cronjob config
        var cronjobTime =  6;// 6 Minutes
        if($response.status == 'collecting' && $response.readBatch == '1' && $response.runningTime > 6*60){

            if($('.sx-cronjob-error.error').length) return;

            var runningTime = Math.floor($response.runningTime / 60);

            var magentoDokuLink = '<a href="https://devdocs.magento.com/guides/m1x/install/installing_install.html#install-cron" target="blank">Installing and Verifying Magento</a>';

            $('.sx-progress-container').after('<p class="sx-cronjob-error error"><span><u>Warning:</u> Magento cronjob configuration seems to be incorrect. (batch execution should take less than '+cronjobTime+' Minutes (best-case <1 Minute) but took already '+runningTime+' Minutes)<br>Without fixing this problem, the SEMKNOX Search won\'t work!</span><br><i>See: '+magentoDokuLink+'</i></p>');

        } else {
            $('.sx-cronjob-error.error').remove();
        }

    }

});